% Auto-generated chapter 55 for muslim
% Hadiths in this chapter: 79

\hadithdefcmd{muslim}{7417}{حَدَّثَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، حَدَّثَنَا عَبْدُ الْعَزِيزِ، - يَعْنِي الدَّرَاوَرْدِيَّ - عَنِ الْعَلاَءِ، عَنْ أَبِيهِ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ الدُّنْيَا سِجْنُ الْمُؤْمِنِ وَجَنَّةُ الْكَافِرِ ‏"‏ ‏.‏\hadithno{7417}\hadithtrans{Abu Huraira reported Allah's Messenger (ﷺ) as saying:The world is a prison-house for a believer and Paradise for a non-believer}}
\hadithdefcmd{muslim}{7418}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ مَسْلَمَةَ بْنِ قَعْنَبٍ، حَدَّثَنَا سُلَيْمَانُ، - يَعْنِي ابْنَ بِلاَلٍ - عَنْ جَعْفَرٍ، عَنْ أَبِيهِ، عَنْ جَابِرِ بْنِ عَبْدِ اللَّهِ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم مَرَّ بِالسُّوقِ دَاخِلاً مِنْ بَعْضِ الْعَالِيَةِ وَالنَّاسُ كَنَفَتَهُ فَمَرَّ بِجَدْىٍ أَسَكَّ مَيِّتٍ فَتَنَاوَلَهُ فَأَخَذَ بِأُذُنِهِ ثُمَّ قَالَ ‏"‏ أَيُّكُمْ يُحِبُّ أَنَّ هَذَا لَهُ بِدِرْهَمٍ ‏"‏ ‏.‏ فَقَالُوا مَا نُحِبُّ أَنَّهُ لَنَا بِشَىْءٍ وَمَا نَصْنَعُ بِهِ قَالَ ‏"‏ أَتُحِبُّونَ أَنَّهُ لَكُمْ ‏"‏ ‏.‏ قَالُوا وَاللَّهِ لَوْ كَانَ حَيًّا كَانَ عَيْبًا فِيهِ لأَنَّهُ أَسَكُّ فَكَيْفَ وَهُوَ مَيِّتٌ فَقَالَ ‏"‏ فَوَاللَّهِ لَلدُّنْيَا أَهْوَنُ عَلَى اللَّهِ مِنْ هَذَا عَلَيْكُمْ ‏"‏ ‏.‏\hadithno{7418}\hadithtrans{Jabir b. Abdullah reported that Allah's Apostle (ﷺ) happened to walk through the bazar coming from the side of 'Aliya and the people were on both his sides. There he found a dead lamb with very short ears. He took hold of his ear and said:Who amongst you would like to have this for a dirham? They said: We do not like to have it even for less than that as it is of no use to us. He said: Do you wish to have it (free of any cost)? They said: By Allah, even if it were alive (we would not have liked to possess that), for there is defect in it as its ear is very short; now it is dead also. Thereupon Allah's Messenger (ﷺ) said: By Allah, this world is more insignificant in the eye of Allah than it (this dead lamb) is in your eye}}
\hadithdefcmd{muslim}{7419}{حَدَّثَنِي مُحَمَّدُ بْنُ الْمُثَنَّى الْعَنَزِيُّ، وَإِبْرَاهِيمُ بْنُ مُحَمَّدِ بْنِ عَرْعَرَةَ السَّامِيُّ، قَالاَ حَدَّثَنَا عَبْدُ الْوَهَّابِ، - يَعْنِيَانِ الثَّقَفِيَّ - عَنْ جَعْفَرٍ، عَنْ أَبِيهِ، عَنْ جَابِرٍ، عَنِ النَّبِيِّ صلى الله عليه وسلم ‏.‏ بِمِثْلِهِ غَيْرَ أَنَّ فِي حَدِيثِ الثَّقَفِيِّ فَلَوْ كَانَ حَيًّا كَانَ هَذَا السَّكَكُ بِهِ عَيْبًا ‏.‏\hadithno{7419}\hadithtrans{Jabir reported Allah's Apostle (ﷺ) narrating a hadith like this with a slight variation of wording}}
\hadithdefcmd{muslim}{7420}{حَدَّثَنَا هَدَّابُ بْنُ خَالِدٍ، حَدَّثَنَا هَمَّامٌ، حَدَّثَنَا قَتَادَةُ، عَنْ مُطَرِّفٍ، عَنْ أَبِيهِ، قَالَ أَتَيْتُ النَّبِيَّ صلى الله عليه وسلم وَهُوَ يَقْرَأُ ‏\{‏ أَلْهَاكُمُ التَّكَاثُرُ‏\}‏ قَالَ ‏ "‏ يَقُولُ ابْنُ آدَمَ مَالِي مَالِي - قَالَ - وَهَلْ لَكَ يَا ابْنَ آدَمَ مِنْ مَالِكَ إِلاَّ مَا أَكَلْتَ فَأَفْنَيْتَ أَوْ لَبِسْتَ فَأَبْلَيْتَ أَوْ تَصَدَّقْتَ فَأَمْضَيْتَ ‏"‏ ‏.‏\hadithno{7420}\hadithtrans{Mutarrif reported on the authority of his father:I came to Allah's Apostle (ﷺ) as he was reciting:" Abundance diverts you" (cii. 1). He said: The son of Adam claims: My wealth, my wealth. And he (the Holy Prophet) said: O son of Adam. is there anything as your belonging except that which you consumed, which you utilised, or which you wore and then it was worn out or you gave as charity and sent it forward?}}
\hadithdefcmd{muslim}{7421}{حَدَّثَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، وَابْنُ، بَشَّارٍ قَالاَ حَدَّثَنَا مُحَمَّدُ بْنُ جَعْفَرٍ، حَدَّثَنَا شُعْبَةُ، وَقَالاَ، جَمِيعًا حَدَّثَنَا ابْنُ أَبِي عَدِيٍّ، عَنْ سَعِيدٍ، ح وَحَدَّثَنَا ابْنُ الْمُثَنَّى، حَدَّثَنَا مُعَاذُ بْنُ هِشَامٍ، حَدَّثَنَا أَبِي كُلُّهُمْ، عَنْ قَتَادَةَ، عَنْ مُطَرِّفٍ، عَنْ أَبِيهِ، قَالَ انْتَهَيْتُ إِلَى النَّبِيِّ صلى الله عليه وسلم ‏.‏ فَذَكَرَ بِمِثْلِ حَدِيثِ هَمَّامٍ ‏.‏\hadithno{7421}\hadithtrans{Mutarrif reported on the authority of his father:I went to Allah's Apostle (ﷺ). The rest of the hadith is the same}}
\hadithdefcmd{muslim}{7422}{حَدَّثَنِي سُوَيْدُ بْنُ سَعِيدٍ، حَدَّثَنَا حَفْصُ بْنُ مَيْسَرَةَ، عَنِ الْعَلاَءِ، عَنْ أَبِيهِ، عَنْ أَبِي، هُرَيْرَةَ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ يَقُولُ الْعَبْدُ مَالِي مَالِي إِنَّمَا لَهُ مِنْ مَالِهِ ثَلاَثٌ مَا أَكَلَ فَأَفْنَى أَوْ لَبِسَ فَأَبْلَى أَوْ أَعْطَى فَاقْتَنَى وَمَا سِوَى ذَلِكَ فَهُوَ ذَاهِبٌ وَتَارِكُهُ لِلنَّاسِ ‏"‏ ‏.‏\hadithno{7422}\hadithtrans{Abu Huraira reported Allah's Messenger (ﷺ) as saying:A servant says, My wealth. my wealth, but out of his wealth three things are only his: whatever he eats and makes use of or by means of which he dresses himself and it wears out or he gives as charity, and this is what he stored for himself (as a reward for the Hereafter), and what is beyond this (it is of no use to you) because you are to depart and leave it for other people}}
\hadithdefcmd{muslim}{7423}{وَحَدَّثَنِيهِ أَبُو بَكْرِ بْنُ إِسْحَاقَ، أَخْبَرَنَا ابْنُ أَبِي مَرْيَمَ، أَخْبَرَنَا مُحَمَّدُ بْنُ جَعْفَرٍ، أَخْبَرَنِي الْعَلاَءُ بْنُ عَبْدِ الرَّحْمَنِ، بِهَذَا الإِسْنَادِ مِثْلَهُ ‏.‏\hadithno{7423}\hadithtrans{This hadith has been narrated on the authority of al-'Ala' b. 'Abd al-Rahman with the same chain of transmitters}}
\hadithdefcmd{muslim}{7424}{حَدَّثَنَا يَحْيَى بْنُ يَحْيَى التَّمِيمِيُّ، وَزُهَيْرُ بْنُ حَرْبٍ، كِلاَهُمَا عَنِ ابْنِ عُيَيْنَةَ، قَالَ يَحْيَى أَخْبَرَنَا سُفْيَانُ بْنُ عُيَيْنَةَ، عَنْ عَبْدِ اللَّهِ بْنِ أَبِي بَكْرٍ، قَالَ سَمِعْتُ أَنَسَ بْنَ مَالِكٍ، يَقُولُ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ يَتْبَعُ الْمَيِّتَ ثَلاَثَةٌ فَيَرْجِعُ اثْنَانِ وَيَبْقَى وَاحِدٌ يَتْبَعُهُ أَهْلُهُ وَمَالُهُ وَعَمَلُهُ فَيَرْجِعُ أَهْلُهُ وَمَالُهُ وَيَبْقَى عَمَلُهُ ‏"‏ ‏.‏\hadithno{7424}\hadithtrans{Anas b. Malik reported Allah's Messenger (ﷺ) as saying:Three things follow the bier of a dead man. Two of them come back and one is left with him: the members of his family, wealth and his good deeds. The members of his family and wealth come back and the deeds alone are left with him}}
\hadithdefcmd{muslim}{7425}{حَدَّثَنِي حَرْمَلَةُ بْنُ يَحْيَى بْنِ عَبْدِ اللَّهِ، - يَعْنِي ابْنَ حَرْمَلَةَ بْنِ عِمْرَانَ التُّجِيبِيَّ - أَخْبَرَنَا ابْنُ وَهْبٍ، أَخْبَرَنِي يُونُسُ، عَنِ ابْنِ شِهَابٍ، عَنْ عُرْوَةَ بْنِ الزُّبَيْرِ، أَنَّ الْمِسْوَرَ بْنَ مَخْرَمَةَ، أَخْبَرَهُ أَنَّ عَمْرَو بْنَ عَوْفٍ وَهُوَ حَلِيفُ بَنِي عَامِرِ بْنِ لُؤَىٍّ وَكَانَ شَهِدَ بَدْرًا مَعَ رَسُولِ اللَّهِ صلى الله عليه وسلم أَخْبَرَهُ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم بَعَثَ أَبَا عُبَيْدَةَ بْنَ الْجَرَّاحِ إِلَى الْبَحْرَيْنِ يَأْتِي بِجِزْيَتِهَا وَكَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم هُوَ صَالَحَ أَهْلَ الْبَحْرَيْنِ وَأَمَّرَ عَلَيْهِمُ الْعَلاَءَ بْنَ الْحَضْرَمِيِّ فَقَدِمَ أَبُو عُبَيْدَةَ بِمَالٍ مِنَ الْبَحْرَيْنِ فَسَمِعَتِ الأَنْصَارُ بِقُدُومِ أَبِي عُبَيْدَةَ فَوَافَوْا صَلاَةَ الْفَجْرِ مَعَ رَسُولِ اللَّهِ صلى الله عليه وسلم فَلَمَّا صَلَّى رَسُولُ اللَّهِ صلى الله عليه وسلم انْصَرَفَ فَتَعَرَّضُوا لَهُ فَتَبَسَّمَ رَسُولُ اللَّهِ صلى الله عليه وسلم حِينَ رَآهُمْ ثُمَّ قَالَ ‏"‏ أَظُنُّكُمْ سَمِعْتُمْ أَنَّ أَبَا عُبَيْدَةَ قَدِمَ بِشَىْءٍ مِنَ الْبَحْرَيْنِ ‏"‏ ‏.‏ فَقَالُوا أَجَلْ يَا رَسُولَ اللَّهِ قَالَ ‏"‏ ‏"‏ فَأَبْشِرُوا وَأَمِّلُوا مَا يَسُرُّكُمْ فَوَاللَّهِ مَا الْفَقْرَ أَخْشَى عَلَيْكُمْ ‏.‏ وَلَكِنِّي أَخْشَى عَلَيْكُمْ أَنْ تُبْسَطَ الدُّنْيَا عَلَيْكُمْ كَمَا بُسِطَتْ عَلَى مَنْ كَانَ قَبْلَكُمْ فَتَنَافَسُوهَا كَمَا تَنَافَسُوهَا وَتُهْلِكَكُمْ كَمَا أَهْلَكَتْهُمْ ‏"‏ ‏.‏\hadithno{7425}\hadithtrans{Amr b. `Auf, who was an ally of Banu `Amir b. Luwayy (and he was one amongst them) who participated in Badr along with Allah's Messenger (ﷺ) reported that, Allah's Messenger (ﷺ) sent Abu `Ubaida b. Al-Jarrah to Bahrain for collecting Jizya and Allah's Messenger (ﷺ) had made a truce with the people of Bahrain and had appointed `Ala' b. Hadrami and Abu `Ubaida (for this purpose). They came with wealth from Bahrain and the Ansar heard about the arrival of Abu `Ubaida and they had observed the dawn prayer along with Allah's Messenger (ﷺ). When Allah's Messenger (ﷺ) had finished the prayer, they (the Ansar) came before him and Allah's Messenger (ﷺ) smiled as he saw them and then said:I think you have heard about the arrival of Abu `Ubaida with goods from Bahrain. They said: Allah's Messenger, yes, it is so. Thereupon he said: Be happy and be hopeful of that which gives you delight. By Allah, it is not the poverty about which I fear in regard to you but I am afraid in your case that (the worldly) riches way be given to you as were given to those who had gone before you and you begin to vie with one another for them as they vied for them, and these may destroy you as these destroyed them}}
\hadithdefcmd{muslim}{7426}{حَدَّثَنَا الْحَسَنُ بْنُ عَلِيٍّ الْحُلْوَانِيُّ، وَعَبْدُ بْنُ حُمَيْدٍ، جَمِيعًا عَنْ يَعْقُوبَ بْنِ إِبْرَاهِيمَ، بْنِ سَعْدٍ حَدَّثَنَا أَبِي، عَنْ صَالِحٍ، ح وَحَدَّثَنَا عَبْدُ اللَّهِ بْنُ عَبْدِ الرَّحْمَنِ الدَّارِمِيُّ، أَخْبَرَنَا أَبُو الْيَمَانِ أَخْبَرَنَا شُعَيْبٌ، كِلاَهُمَا عَنِ الزُّهْرِيِّ، بِإِسْنَادِ يُونُسَ وَمِثْلِ حَدِيثِهِ غَيْرَ أَنَّ فِي حَدِيثِ صَالِحٍ ‏ "‏ وَتُلْهِيَكُمْ كَمَا أَلْهَتْهُمْ ‏"‏ ‏.‏\hadithno{7426}\hadithtrans{This hadith has been narrated on the authority of Zuhri as reported by Yunus with a slight variation of wording}}
\hadithdefcmd{muslim}{7427}{حَدَّثَنَا عَمْرُو بْنُ سَوَّادٍ الْعَامِرِيُّ، أَخْبَرَنَا عَبْدُ اللَّهِ بْنُ وَهْبٍ، أَخْبَرَنِي عَمْرُو بْنُ، الْحَارِثِ أَنَّ بَكْرَ بْنَ سَوَادَةَ، حَدَّثَهُ أَنَّ يَزِيدَ بْنَ رَبَاحٍ - هُوَ أَبُو فِرَاسٍ مَوْلَى عَبْدِ اللَّهِ بْنِ عَمْرِو بْنِ الْعَاصِ - حَدَّثَهُ عَنْ عَبْدِ اللَّهِ بْنِ عَمْرِو بْنِ الْعَاصِ، عَنْ رَسُولِ اللَّهِ صلى الله عليه وسلم أَنَّهُ قَالَ ‏"‏ إِذَا فُتِحَتْ عَلَيْكُمْ فَارِسُ وَالرُّومُ أَىُّ قَوْمٍ أَنْتُمْ ‏"‏ ‏.‏ قَالَ عَبْدُ الرَّحْمَنِ بْنُ عَوْفٍ نَقُولُ كَمَا أَمَرَنَا اللَّهُ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ أَوْ غَيْرَ ذَلِكَ تَتَنَافَسُونَ ثُمَّ تَتَحَاسَدُونَ ثُمَّ تَتَدَابَرُونَ ثُمَّ تَتَبَاغَضُونَ أَوْ نَحْوَ ذَلِكَ ثُمَّ تَنْطَلِقُونَ فِي مَسَاكِينِ الْمُهَاجِرِينَ فَتَجْعَلُونَ بَعْضَهُمْ عَلَى رِقَابِ بَعْضٍ ‏"‏ ‏.‏\hadithno{7427}\hadithtrans{Abdullah b. `Amr b. al-`As reported that Allah's Messenger (ﷺ) said:How would you be, O people, when Persia and Rome would be conquered for you? `Abd ar-Rahman b `Auf said: We would say as Allah has commanded us and we would express our gratitude to Allah. Thereupon Allah's Messenger (ﷺ) said: Nothing else besides it? You would (in fact) vie with one another, then you would feel jealous, then your relations would be estranged and then you will bear enmity against one another, or something to the same effect. Then you would go to the poor emigrants and would make some the masters of the others}}
\hadithdefcmd{muslim}{7428}{حَدَّثَنَا يَحْيَى بْنُ يَحْيَى، وَقُتَيْبَةُ بْنُ سَعِيدٍ، قَالَ قُتَيْبَةُ حَدَّثَنَا وَقَالَ، يَحْيَى أَخْبَرَنَا الْمُغِيرَةُ بْنُ عَبْدِ الرَّحْمَنِ الْحِزَامِيُّ، عَنْ أَبِي الزِّنَادِ، عَنِ الأَعْرَجِ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ إِذَا نَظَرَ أَحَدُكُمْ إِلَى مَنْ فُضِّلَ عَلَيْهِ فِي الْمَالِ وَالْخَلْقِ فَلْيَنْظُرْ إِلَى مَنْ هُوَ أَسْفَلَ مِنْهُ مِمَّنْ فُضِّلَ عَلَيْهِ ‏"‏ ‏.‏\hadithno{7428}\hadithtrans{Abu Huraira reported that Allah's Messenger (ﷺ) said:When one of you looks at one who stands at a higher level than you in regard to wealth and physical structure he should also see one who stands at a lower level than you in regard to these things (in which he stands) at a higher level (as compared to him)}}
\hadithdefcmd{muslim}{7429}{حَدَّثَنَا مُحَمَّدُ بْنُ رَافِعٍ، حَدَّثَنَا عَبْدُ الرَّزَّاقِ، حَدَّثَنَا مَعْمَرٌ، عَنْ هَمَّامِ بْنِ مُنَبِّهٍ، عَنْ أَبِي هُرَيْرَةَ، عَنِ النَّبِيِّ صلى الله عليه وسلم بِمِثْلِ حَدِيثِ أَبِي الزِّنَادِ سَوَاءً ‏.‏\hadithno{7429}\hadithtrans{This hadith has been narrated on the authority of Abu Huraira through another chain of transmitters}}
\hadithdefcmd{muslim}{7430}{وَحَدَّثَنِي زُهَيْرُ بْنُ حَرْبٍ، حَدَّثَنَا جَرِيرٌ، ح وَحَدَّثَنَا أَبُو كُرَيْبٍ، حَدَّثَنَا أَبُو مُعَاوِيَةَ، ح وَحَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، - وَاللَّفْظُ لَهُ - حَدَّثَنَا أَبُو مُعَاوِيَةَ، وَوَكِيعٌ، عَنِ الأَعْمَشِ، عَنْ أَبِي صَالِحٍ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ انْظُرُوا إِلَى مَنْ أَسْفَلَ مِنْكُمْ وَلاَ تَنْظُرُوا إِلَى مَنْ هُوَ فَوْقَكُمْ فَهُوَ أَجْدَرُ أَنْ لاَ تَزْدَرُوا نِعْمَةَ اللَّهِ ‏"‏ ‏.‏ قَالَ أَبُو مُعَاوِيَةَ ‏"‏ عَلَيْكُمْ ‏"‏ ‏.‏\hadithno{7430}\hadithtrans{Abu Huraira reported Allah's Messenger (ﷺ) as saying:Look at those who stand at a lower level than you but don't look at those who stand at a higher level than you, for that is better-suited that you do not disparage Allah's favors. In the chain narrated by Abu Mu'awiya's he said: Upon you}}
\hadithdefcmd{muslim}{7431}{حَدَّثَنَا شَيْبَانُ بْنُ فَرُّوخَ، حَدَّثَنَا هَمَّامٌ، حَدَّثَنَا إِسْحَاقُ بْنُ عَبْدِ اللَّهِ بْنِ أَبِي طَلْحَةَ، حَدَّثَنِي عَبْدُ الرَّحْمَنِ بْنُ أَبِي عَمْرَةَ، أَنَّ أَبَا هُرَيْرَةَ، حَدَّثَهُ أَنَّهُ، سَمِعَ النَّبِيَّ صلى الله عليه وسلم يَقُولُ ‏"‏ إِنَّ ثَلاَثَةً فِي بَنِي إِسْرَائِيلَ أَبْرَصَ وَأَقْرَعَ وَأَعْمَى فَأَرَادَ اللَّهُ أَنْ يَبْتَلِيَهُمْ فَبَعَثَ إِلَيْهِمْ مَلَكًا فَأَتَى الأَبْرَصَ فَقَالَ أَىُّ شَىْءٍ أَحَبُّ إِلَيْكَ قَالَ لَوْنٌ حَسَنٌ وَجِلْدٌ حَسَنٌ وَيَذْهَبُ عَنِّي الَّذِي قَدْ قَذِرَنِي النَّاسُ ‏.‏ قَالَ فَمَسَحَهُ فَذَهَبَ عَنْهُ قَذَرُهُ وَأُعْطِيَ لَوْنًا حَسَنًا وَجِلْدًا حَسَنًا قَالَ فَأَىُّ الْمَالِ أَحَبُّ إِلَيْكَ قَالَ الإِبِلُ - أَوْ قَالَ الْبَقَرُ شَكَّ إِسْحَاقُ - إِلاَّ أَنَّ الأَبْرَصَ أَوِ الأَقْرَعَ قَالَ أَحَدُهُمَا الإِبِلُ وَقَالَ الآخَرُ الْبَقَرُ - قَالَ فَأُعْطِيَ نَاقَةً عُشَرَاءَ فَقَالَ بَارَكَ اللَّهُ لَكَ فِيهَا - قَالَ - فَأَتَى الأَقْرَعَ فَقَالَ أَىُّ شَىْءٍ أَحَبُّ إِلَيْكَ قَالَ شَعَرٌ حَسَنٌ وَيَذْهَبُ عَنِّي هَذَا الَّذِي قَذِرَنِي النَّاسُ ‏.‏ قَالَ فَمَسَحَهُ فَذَهَبَ عَنْهُ وَأُعْطِيَ شَعَرًا حَسَنًا - قَالَ - فَأَىُّ الْمَالِ أَحَبُّ إِلَيْكَ قَالَ الْبَقَرُ ‏.‏ فَأُعْطِيَ بَقَرَةً حَامِلاً فَقَالَ بَارَكَ اللَّهُ لَكَ فِيهَا - قَالَ - فَأَتَى الأَعْمَى فَقَالَ أَىُّ شَىْءٍ أَحَبُّ إِلَيْكَ قَالَ أَنْ يَرُدَّ اللَّهُ إِلَىَّ بَصَرِي فَأُبْصِرَ بِهِ النَّاسَ - قَالَ - فَمَسَحَهُ فَرَدَّ اللَّهُ إِلَيْهِ بَصَرَهُ ‏.‏ قَالَ فَأَىُّ الْمَالِ أَحَبُّ إِلَيْكَ قَالَ الْغَنَمُ ‏.‏ فَأُعْطِيَ شَاةً وَالِدًا فَأُنْتِجَ هَذَانِ وَوَلَّدَ هَذَا - قَالَ - فَكَانَ لِهَذَا وَادٍ مِنَ الإِبِلِ وَلِهَذَا وَادٍ مِنَ الْبَقَرِ وَلِهَذَا وَادٍ مِنَ الْغَنَمِ ‏.‏ قَالَ ثُمَّ إِنَّهُ أَتَى الأَبْرَصَ فِي صُورَتِهِ وَهَيْئَتِهِ فَقَالَ رَجُلٌ مِسْكِينٌ قَدِ انْقَطَعَتْ بِيَ الْحِبَالُ فِي سَفَرِي فَلاَ بَلاَغَ لِيَ الْيَوْمَ إِلاَّ بِاللَّهِ ثُمَّ بِكَ أَسْأَلُكَ بِالَّذِي أَعْطَاكَ اللَّوْنَ الْحَسَنَ وَالْجِلْدَ الْحَسَنَ وَالْمَالَ بَعِيرًا أَتَبَلَّغُ عَلَيْهِ فِي سَفَرِي ‏.‏ فَقَالَ الْحُقُوقُ كَثِيرَةٌ ‏.‏ فَقَالَ لَهُ كَأَنِّي أَعْرِفُكَ أَلَمْ تَكُنْ أَبْرَصَ يَقْذَرُكَ النَّاسُ فَقِيرًا فَأَعْطَاكَ اللَّهُ فَقَالَ إِنَّمَا وَرِثْتُ هَذَا الْمَالَ كَابِرًا عَنْ كَابِرٍ ‏.‏ فَقَالَ إِنْ كُنْتَ كَاذِبًا فَصَيَّرَكَ اللَّهُ إِلَى مَا كُنْتَ ‏.‏ قَالَ وَأَتَى الأَقْرَعَ فِي صُورَتِهِ فَقَالَ لَهُ مِثْلَ مَا قَالَ لِهَذَا وَرَدَّ عَلَيْهِ مِثْلَ مَا رَدَّ عَلَى هَذَا فَقَالَ إِنْ كُنْتَ كَاذِبًا فَصَيَّرَكَ اللَّهُ إِلَى مَا كُنْتَ ‏.‏ قَالَ وَأَتَى الأَعْمَى فِي صُورَتِهِ وَهَيْئَتِهِ فَقَالَ رَجُلٌ مِسْكِينٌ وَابْنُ سَبِيلٍ انْقَطَعَتْ بِيَ الْحِبَالُ فِي سَفَرِي فَلاَ بَلاَغَ لِيَ الْيَوْمَ إِلاَّ بِاللَّهِ ثُمَّ بِكَ أَسْأَلُكَ بِالَّذِي رَدَّ عَلَيْكَ بَصَرَكَ شَاةً أَتَبَلَّغُ بِهَا فِي سَفَرِي فَقَالَ قَدْ كُنْتُ أَعْمَى فَرَدَّ اللَّهُ إِلَىَّ بَصَرِي فَخُذْ مَا شِئْتَ وَدَعْ مَا شِئْتَ فَوَاللَّهِ لاَ أَجْهَدُكَ الْيَوْمَ شَيْئًا أَخَذْتَهُ لِلَّهِ فَقَالَ أَمْسِكْ مَالَكَ فَإِنَّمَا ابْتُلِيتُمْ فَقَدْ رُضِيَ عَنْكَ وَسُخِطَ عَلَى صَاحِبَيْكَ ‏.‏\hadithno{7431}\hadithtrans{Abu Huraira, narrated that he heard Allah's Messenger (ﷺ) as saying:There were three persons in Bani Isra'il, one suffering from leprosy, the other bald-headed and the third one blind. Allah decided to test them. So He sent an angel who came to the one who was suffering from leprosy and said: Which thing do you like most? He said: Beautiful colour and fine skin and removal of that which makes me detestable in the eye of people. He wiped him and his illness was no more and he was conferred upon beautiful colour and beautiful skin. He (the angel) again said: Which property do you like most? He said: Camels, or he said: The cow the narrator is, however, doubtful about it, but (out of the persons) suffering from leprosy or baldness one of them definitely said: The camel. And the other one said: Cow. And he (one who demanded camel) was bestowed upon a she-camel, in an advanced stage of pregnancy, and while giving he said: May Allah bless you in this. Then he came to the bald-headed person and said: Which thing do you like most? He said: Beautiful hair and that (this baldness) may be removed from me because of which people hate me. He wiped his body and his illness was removed and he was bestowed upon beautiful hair, and the angel said: Which wealth do you like most? He said: The cow. And he was given a pregnant cow and while handing it over to him he (the angel) said: May Allah bless you in this. Then he came to the blind man and he said: Which thing do you like most? He said: Allah should restore my eyesight so that I should be able to see people with the help of that. He wiped his body and Allah restored to him his eyesight, and he (the angel) also said: Which wealth do you like most? He said: The flock of sheep. And he was given a pregnant goat and that gave birth to young ones and it so happened that one valley abounded in camels and the other one in cows and the third one in sheep. He then came to the one who had suffered from leprosy in his (old) form and shape and he said: I am a poor person and my provision has run short in my journey and there is none to take me to my destination except with the help of Allah and your favour. I beg of you in His name Who gave you fine colour and fine skin, and the camel in the shape of wealth (to confer upon me) a camel which should carry me in my journey. He said: I have many responsibilities to discharge. Thereupon he said: I perceive as if I recognise you. Were you not suffering from leprosy whom people hated and you were a destitute and Allah conferred upon you (wealth)? He said: I have inherited this property from my forefathers. Thereupon he said: If you are a liar may Allah change you to that very position in which you had been. He then came to the one who was bald-headed in his (old) form and said to him the same what he had said to him (one suffering from leprosy) and he gave him the same reply as he had given him and he said: If you are a liar, may Allah turn you to your previous position in which you had been. And then he came to the blind man in his (old) form and shape and he said: I am a destitute person and a wayfarer. My provision have ran short and today there is no way to reach the destination but with the help of Allah and then with your help and I beg of you in the (name) of One Who restored your eyesight and gave you the flock of sheep to give me a sheep by which I should be able to make my provisions for the journey. He said: I was blind and Allah restored to me my eyesight; you take whatever you like and leave whatever you like. By Allah, I shall not stand in your way today for what you take in the name of God. Thereupon, he said: You keep with you what you have (in your possession). The fact is that you three were put to test and Allah is well pleased with you and He is annoyed with your companions}}
\hadithdefcmd{muslim}{7432}{حَدَّثَنَا إِسْحَاقُ بْنُ إِبْرَاهِيمَ، وَعَبَّاسُ بْنُ عَبْدِ الْعَظِيمِ، - وَاللَّفْظُ لإِسْحَاقَ - قَالَ عَبَّاسٌ حَدَّثَنَا وَقَالَ، إِسْحَاقُ أَخْبَرَنَا - أَبُو بَكْرٍ الْحَنَفِيُّ، حَدَّثَنَا بُكَيْرُ بْنُ مِسْمَارٍ، حَدَّثَنِي عَامِرُ بْنُ سَعْدٍ، قَالَ كَانَ سَعْدُ بْنُ أَبِي وَقَّاصٍ فِي إِبِلِهِ فَجَاءَهُ ابْنُهُ عُمَرُ فَلَمَّا رَآهُ سَعْدٌ قَالَ أَعُوذُ بِاللَّهِ مِنْ شَرِّ هَذَا الرَّاكِبِ فَنَزَلَ فَقَالَ لَهُ أَنَزَلْتَ فِي إِبِلِكَ وَغَنَمِكَ وَتَرَكْتَ النَّاسَ يَتَنَازَعُونَ الْمُلْكَ بَيْنَهُمْ فَضَرَبَ سَعْدٌ فِي صَدْرِهِ فَقَالَ اسْكُتْ سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏ "‏ إِنَّ اللَّهَ يُحِبُّ الْعَبْدَ التَّقِيَّ الْغَنِيَّ الْخَفِيَّ ‏"‏ ‏.‏\hadithno{7432}\hadithtrans{It is reported on the authority of Amir b. Sa'd that Sa'd b. Abi Waqqas was in the fold of his camels that his son 'Umar came to him. When Sa'd saw him he said:I seek refuge with Allah from the mischief of this rider. And as he got down he said to him: You are busy with your camels and your sheep and you have abandoned people who are contending with one another for kingdom. Sa'd struck his chest and said: Keep quite. I heard Allah's Messenger (ﷺ) as saying: Allah loves the servant who is God-conscious and is free from want and is hidden (from the view of people)}}
\hadithdefcmd{muslim}{7433}{حَدَّثَنَا يَحْيَى بْنُ حَبِيبٍ الْحَارِثِيُّ، حَدَّثَنَا الْمُعْتَمِرُ، قَالَ سَمِعْتُ إِسْمَاعِيلَ، عَنْ قَيْسٍ، عَنْ سَعْدٍ، ح وَحَدَّثَنَا مُحَمَّدُ بْنُ عَبْدِ اللَّهِ بْنِ نُمَيْرٍ، حَدَّثَنَا أَبِي وَابْنُ، بِشْرٍ قَالاَ حَدَّثَنَا إِسْمَاعِيلُ، عَنْ قَيْسٍ، قَالَ سَمِعْتُ سَعْدَ بْنَ أَبِي وَقَّاصٍ، يَقُولُ وَاللَّهِ إِنِّي لأَوَّلُ رَجُلٍ مِنَ الْعَرَبِ رَمَى بِسَهْمٍ فِي سَبِيلِ اللَّهِ وَلَقَدْ كُنَّا نَغْزُو مَعَ رَسُولِ اللَّهِ صلى الله عليه وسلم مَا لَنَا طَعَامٌ نَأْكُلُهُ إِلاَّ وَرَقُ الْحُبْلَةِ وَهَذَا السَّمُرُ حَتَّى إِنَّ أَحَدَنَا لَيَضَعُ كَمَا تَضَعُ الشَّاةُ ثُمَّ أَصْبَحَتْ بَنُو أَسَدٍ تُعَزِّرُنِي عَلَى الدِّينِ لَقَدْ خِبْتُ إِذًا وَضَلَّ عَمَلِي وَلَمْ يَقُلِ ابْنُ نُمَيْرٍ إِذًا ‏.‏\hadithno{7433}\hadithtrans{Sa'd b. Abu Waqqas is reported to have, said:By Allah, I am the first person amongst the Arabs to throw an arrow in the cause of Allah and we used to go with Allah's Messenger (ﷺ) and there was no food for us to eat but only the leaves of hubla and samur trees (they are wild trees) and as a result thereof one amongst us would relieve himself as does the goat. (How strange it is) that now the people of Banu Asad (the progeny of Zubair) instruct me in religion and try to impose punishment upon me (in regard to it). If it is so (that I am so ignorant of religion), then indeed, I am undone and my deeds have been lost. Ibn Numair, however, did not make a mention of the word (idhan) thus? (in his narration)}}
\hadithdefcmd{muslim}{7434}{وَحَدَّثَنَاهُ يَحْيَى بْنُ يَحْيَى، أَخْبَرَنَا وَكِيعٌ، عَنْ إِسْمَاعِيلَ بْنِ أَبِي خَالِدٍ، بِهَذَا الإِسْنَادِ وَقَالَ حَتَّى إِنْ كَانَ أَحَدُنَا لَيَضَعُ كَمَا تَضَعُ الْعَنْزُ مَا يَخْلِطُهُ بِشَىْءٍ ‏.‏\hadithno{7434}\hadithtrans{This hadith has been narrated on the authority of Isma'il b. Khalid with the same chain of transmitters and the words are:" One amongst us would relieve himself as the goats do without anything mixing with its excrement}}
\hadithdefcmd{muslim}{7435}{حَدَّثَنَا شَيْبَانُ بْنُ فَرُّوخَ، حَدَّثَنَا سُلَيْمَانُ بْنُ الْمُغِيرَةِ، حَدَّثَنَا حُمَيْدُ بْنُ هِلاَلٍ، عَنْ خَالِدِ بْنِ عُمَيْرٍ الْعَدَوِيِّ، قَالَ خَطَبَنَا عُتْبَةُ بْنُ غَزْوَانَ فَحَمِدَ اللَّهَ وَأَثْنَى عَلَيْهِ ثُمَّ قَالَ أَمَّا بَعْدُ فَإِنَّ الدُّنْيَا قَدْ آذَنَتْ بِصُرْمٍ وَوَلَّتْ حَذَّاءَ وَلَمْ يَبْقَ مِنْهَا إِلاَّ صُبَابَةٌ كَصُبَابَةِ الإِنَاءِ يَتَصَابُّهَا صَاحِبُهَا وَإِنَّكُمْ مُنْتَقِلُونَ مِنْهَا إِلَى دَارٍ لاَ زَوَالَ لَهَا فَانْتَقِلُوا بِخَيْرِ مَا بِحَضْرَتِكُمْ فَإِنَّهُ قَدْ ذُكِرَ لَنَا أَنَّ الْحَجَرَ يُلْقَى مِنْ شَفَةِ جَهَنَّمَ فَيَهْوِي فِيهَا سَبْعِينَ عَامًا لاَ يُدْرِكُ لَهَا قَعْرًا وَوَاللَّهِ لَتُمْلأَنَّ أَفَعَجِبْتُمْ وَلَقَدْ ذُكِرَ لَنَا أَنَّ مَا بَيْنَ مِصْرَاعَيْنِ مِنْ مَصَارِيعِ الْجَنَّةِ مَسِيرَةُ أَرْبَعِينَ سَنَةً وَلَيَأْتِيَنَّ عَلَيْهَا يَوْمٌ وَهُوَ كَظِيظٌ مِنَ الزِّحَامِ وَلَقَدْ رَأَيْتُنِي سَابِعَ سَبْعَةٍ مَعَ رَسُولِ اللَّهِ صلى الله عليه وسلم مَا لَنَا طَعَامٌ إِلاَّ وَرَقُ الشَّجَرِ حَتَّى قَرِحَتْ أَشْدَاقُنَا فَالْتَقَطْتُ بُرْدَةً فَشَقَقْتُهَا بَيْنِي وَبَيْنَ سَعْدِ بْنِ مَالِكٍ فَاتَّزَرْتُ بِنِصْفِهَا وَاتَّزَرَ سَعْدٌ بِنِصْفِهَا فَمَا أَصْبَحَ الْيَوْمَ مِنَّا أَحَدٌ إِلاَّ أَصْبَحَ أَمِيرًا عَلَى مِصْرٍ مِنَ الأَمْصَارِ وَإِنِّي أَعُوذُ بِاللَّهِ أَنْ أَكُونَ فِي نَفْسِي عَظِيمًا وَعِنْدَ اللَّهِ صَغِيرًا وَإِنَّهَا لَمْ تَكُنْ نُبُوَّةٌ قَطُّ إِلاَّ تَنَاسَخَتْ حَتَّى يَكُونَ آخِرُ عَاقِبَتِهَا مُلْكًا فَسَتَخْبُرُونَ وَتُجَرِّبُونَ الأُمَرَاءَ بَعْدَنَا ‏.‏\hadithno{7435}\hadithtrans{Umair al-'Adawi reported:'Utba b. Ghazwan delivered us a sermon and he praised Allah and lauded Him, then said: Now coming to the point, verily the world has been given the news of its end and that too quite early. Nothing would be left out of it but only water left in the utensil which its owner leaves, and you are going to shift to an abode which knows no end, and you should shift with the good before you, for we have been told that a stone would be thrown at one side of the Hell and it would go down even for seventy years but would not be able to reach its bottom. By Allah, it would be fully packed. Do you find it something strange, and it has been mentioned that there yawns a distance which one would be able to cover in forty years from one end to another of Paradise, and a day would come when it would be fully packed and you must be knowing that I was the seventh amongst seven who had been with Allah's Messenger (ﷺ) and we had nothing to eat but the leaves of the tree until the corners of the mouth were injured. We found a sheet which we tore in two and divided between myself and Sa'd b. Malik. I made the lower garment with halt of it and so did Sa'd make the lower garment with half of it and today there is none amongst us who has not become the governor of a city from amongst the cities (of the Islamic Commonwealth) and I seek refuge with Allah that I should consider myself great whereas I am insignificant in the eye of Allah. Prophethood does not remain for ever and its impact fades with the result that it changes eventually into kingship, and you would soon come to know and experience those rulers who would come after us and see (how far they are from religion)}}
\hadithdefcmd{muslim}{7436}{وَحَدَّثَنِي إِسْحَاقُ بْنُ عُمَرَ بْنِ سَلِيطٍ، حَدَّثَنَا سُلَيْمَانُ بْنُ الْمُغِيرَةِ، حَدَّثَنَا حُمَيْدُ بْنُ، هِلاَلٍ عَنْ خَالِدِ بْنِ عُمَيْرٍ، وَقَدْ أَدْرَكَ الْجَاهِلِيَّةَ قَالَ خَطَبَ عُتْبَةُ بْنُ غَزْوَانَ وَكَانَ أَمِيرًا عَلَى الْبَصْرَةِ ‏.‏ فَذَكَرَ نَحْوَ حَدِيثِ شَيْبَانَ ‏.‏\hadithno{7436}\hadithtrans{Khalid b. 'Umair reported and he had seen the pre-Islamic days also, that 'Uqba b. Ghazwan delivered this address and he was the governor of Basra. The rest of the hadith is the same as transmitted by Shaiban}}
\hadithdefcmd{muslim}{7437}{وَحَدَّثَنَا أَبُو كُرَيْبٍ، مُحَمَّدُ بْنُ الْعَلاَءِ حَدَّثَنَا وَكِيعٌ، عَنْ قُرَّةَ بْنِ خَالِدٍ، عَنْ حُمَيْدِ، بْنِ هِلاَلٍ عَنْ خَالِدِ بْنِ عُمَيْرٍ، قَالَ سَمِعْتُ عُتْبَةَ بْنَ غَزْوَانَ، يَقُولُ لَقَدْ رَأَيْتُنِي سَابِعَ سَبْعَةٍ مَعَ رَسُولِ اللَّهِ صلى الله عليه وسلم مَا طَعَامُنَا إِلاَّ وَرَقُ الْحُبْلَةِ حَتَّى قَرِحَتْ أَشْدَاقُنَا ‏.‏\hadithno{7437}\hadithtrans{Khalid b. Umair reported:I heard Uqba b. Ghazwan as saving: I found myself as the seventh amongst the seven who had been along with Allah's Messenger (ﷺ). We had nothing to eat but the leaves of hubla (a wild tree) until the corners of our mouths were injured}}
\hadithdefcmd{muslim}{7438}{حَدَّثَنَا مُحَمَّدُ بْنُ أَبِي عُمَرَ، حَدَّثَنَا سُفْيَانُ، عَنْ سُهَيْلِ بْنِ أَبِي صَالِحٍ، عَنْ أَبِيهِ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالُوا يَا رَسُولَ اللَّهِ هَلْ نَرَى رَبَّنَا يَوْمَ الْقِيَامَةِ قَالَ ‏"‏ هَلْ تُضَارُّونَ فِي رُؤْيَةِ الشَّمْسِ فِي الظَّهِيرَةِ لَيْسَتْ فِي سَحَابَةٍ ‏"‏ ‏.‏ قَالُوا لاَ ‏.‏ قَالَ ‏"‏ فَهَلْ تُضَارُّونَ فِي رُؤْيَةِ الْقَمَرِ لَيْلَةَ الْبَدْرِ لَيْسَ فِي سَحَابَةٍ ‏"‏ ‏.‏ قَالُوا لاَ ‏.‏ قَالَ ‏"‏ فَوَالَّذِي نَفْسِي بِيَدِهِ لاَ تُضَارُّونَ فِي رُؤْيَةِ رَبِّكُمْ إِلاَّ كَمَا تُضَارُّونَ فِي رُؤْيَةِ أَحَدِهِمَا - قَالَ - فَيَلْقَى الْعَبْدَ فَيَقُولُ أَىْ فُلْ أَلَمْ أُكْرِمْكَ وَأُسَوِّدْكَ وَأُزَوِّجْكَ وَأُسَخِّرْ لَكَ الْخَيْلَ وَالإِبِلَ وَأَذَرْكَ تَرْأَسُ وَتَرْبَعُ فَيَقُولُ بَلَى ‏.‏ قَالَ فَيَقُولُ أَفَظَنَنْتَ أَنَّكَ مُلاَقِيَّ فَيَقُولُ لاَ ‏.‏ فَيَقُولُ فَإِنِّي أَنْسَاكَ كَمَا نَسِيتَنِي ‏.‏ ثُمَّ يَلْقَى الثَّانِيَ فَيَقُولُ أَىْ فُلْ أَلَمْ أُكْرِمْكَ وَأُسَوِّدْكَ وَأُزَوِّجْكَ وَأُسَخِّرْ لَكَ الْخَيْلَ وَالإِبِلَ وَأَذَرْكَ تَرْأَسُ وَتَرْبَعُ فَيَقُولُ بَلَى أَىْ رَبِّ ‏.‏ فَيَقُولُ أَفَظَنَنْتَ أَنَّكَ مُلاَقِيَّ فَيَقُولُ لاَ ‏.‏ فَيَقُولُ فَإِنِّي أَنْسَاكَ كَمَا نَسِيتَنِي ‏.‏ ثُمَّ يَلْقَى الثَّالِثَ فَيَقُولُ لَهُ مِثْلَ ذَلِكَ فَيَقُولُ يَا رَبِّ آمَنْتُ بِكَ وَبِكِتَابِكَ وَبِرُسُلِكَ وَصَلَّيْتُ وَصُمْتُ وَتَصَدَّقْتُ ‏.‏ وَيُثْنِي بِخَيْرٍ مَا اسْتَطَاعَ فَيَقُولُ هَا هُنَا إِذًا - قَالَ - ثُمَّ يُقَالُ لَهُ الآنَ نَبْعَثُ شَاهِدَنَا عَلَيْكَ ‏.‏ وَيَتَفَكَّرُ فِي نَفْسِهِ مَنْ ذَا الَّذِي يَشْهَدُ عَلَىَّ فَيُخْتَمُ عَلَى فِيهِ وَيُقَالُ لِفَخِذِهِ وَلَحْمِهِ وَعِظَامِهِ انْطِقِي فَتَنْطِقُ فَخِذُهُ وَلَحْمُهُ وَعِظَامُهُ بِعَمَلِهِ وَذَلِكَ لِيُعْذِرَ مِنْ نَفْسِهِ ‏.‏ وَذَلِكَ الْمُنَافِقُ وَذَلِكَ الَّذِي يَسْخَطُ اللَّهُ عَلَيْهِ ‏"‏ ‏.‏\hadithno{7438}\hadithtrans{Abu Huraira reported that they (the Companions of the Holy Prophet) said:Allah's Messenger, will we be able to see our Lord on the Day of Judgment? He said: Do you feel any difficulty in seeing the sun in the noon when there is no cloud over it? They said: No. He again said: Do you feel any difficulty in seeing the moon on the fourteenth night when there is no cloud over it? They said: No. Thereupon he said: By Allah Who is One in Whose Hand is my life. you will not face any difficulty in seeing your Lord but only so much as you feel in seeing one of them. Then Allah would sit in judgment upon the servant and would say: O, so and so, did I not honour you and make you the chief and provide you the spouse and subdue for you horses, camels, and afforded you an opportunity to rule over your subjects? He would say: Yes. And then it would be said: Did you not think that you would meet Us? And he would say: No. Thereupon He (Allah) would say: Well, We forget you as you forgot Us. Then the second person would be brought for judgment. (And Allah would) say: 0, so and so. did We not honour you and make you the chief and make you pair and subdue for you horses and camels and afford you an opportunity to rule over your subjects? He would say: Yes, my Lord. And He (the Lord) would say: Did you not think that you would be meeting Us? And he would say: No. And then He (Allah) would say: Well, I forget you today as you forgot Us. Then the third -one would be brought and He (Allah) would say to him as He said before. And he (the third person) would say: O, my Lord, I affirmed my faith in Thee and in Thy Book and in Thy Messenger and I observed prayer and fasts and gave charity, and he would speak in good terms like this as he would be able to do. And He (Allah) would say: Well, We will bring our witnesses to you. And the man would think in his mind who would bear witness upon him and then his mouth would be sealed and it would be said to his thighs, to his flesh and to his bones to speak and his thighs. flesh and bones would bear witness to his deeds and it would be done so that he should not be able to make any excuse for himself and he would be a hypocrite and Allah would be annoyed with him}}
\hadithdefcmd{muslim}{7439}{حَدَّثَنَا أَبُو بَكْرِ بْنُ النَّضْرِ بْنِ أَبِي النَّضْرِ، حَدَّثَنِي أَبُو النَّضْرِ، هَاشِمُ بْنُ الْقَاسِمِ حَدَّثَنَا عُبَيْدُ اللَّهِ الأَشْجَعِيُّ، عَنْ سُفْيَانَ الثَّوْرِيِّ، عَنْ عُبَيْدٍ الْمُكْتِبِ، عَنْ فُضَيْلٍ، عَنِ الشَّعْبِيِّ، عَنْ أَنَسِ بْنِ مَالِكٍ، قَالَ كُنَّا عِنْدَ رَسُولِ اللَّهِ صلى الله عليه وسلم فَضَحِكَ فَقَالَ ‏"‏ هَلْ تَدْرُونَ مِمَّ أَضْحَكُ ‏"‏ ‏.‏ قَالَ قُلْنَا اللَّهُ وَرَسُولُهُ أَعْلَمُ ‏.‏ قَالَ ‏"‏ مِنْ مُخَاطَبَةِ الْعَبْدِ رَبَّهُ يَقُولُ يَا رَبِّ أَلَمْ تُجِرْنِي مِنَ الظُّلْمِ قَالَ يَقُولُ بَلَى ‏.‏ قَالَ فَيَقُولُ فَإِنِّي لاَ أُجِيزُ عَلَى نَفْسِي إِلاَّ شَاهِدًا مِنِّي قَالَ فَيَقُولُ كَفَى بِنَفْسِكَ الْيَوْمَ عَلَيْكَ شَهِيدًا وَبِالْكِرَامِ الْكَاتِبِينَ شُهُودًا - قَالَ - فَيُخْتَمُ عَلَى فِيهِ فَيُقَالُ لأَرْكَانِهِ انْطِقِي ‏.‏ قَالَ فَتَنْطِقُ بِأَعْمَالِهِ - قَالَ - ثُمَّ يُخَلَّى بَيْنَهُ وَبَيْنَ الْكَلاَمِ - قَالَ - فَيَقُولُ بُعْدًا لَكُنَّ وَسُحْقًا ‏.‏ فَعَنْكُنَّ كُنْتُ أُنَاضِلُ ‏"‏ ‏.‏\hadithno{7439}\hadithtrans{Anas b. Malik reported:We were in the company of Allah's Messenger (ﷺ) when he smiled, and said: Do you know why I laughed? We said: Allah and His Messenger, know best. Thereupon he said: It was because (there came to my mind the) talk which the servant would have with his Lord (on the Day of judgment). He would say: My Lord, have you not guaranteed me protection against injustice? He would say: Yes. Then the servant would say: I do not deem valid any witness against me but my own self, and He would say: Well, enough would be the witness of your self against you and that of the two angels who had been appointed to record your deeds. Then the seal would be set upon his mouth and it would be said to his hands and feet to speak and they would speak of his deeds. Then the mouth would be made free to talk, he would say (to the hands and feet): Be away, let there be curse of Allah upon you. It was for your safety that I contended}}
\hadithdefcmd{muslim}{7440}{حَدَّثَنِي زُهَيْرُ بْنُ حَرْبٍ، حَدَّثَنَا مُحَمَّدُ بْنُ فُضَيْلٍ، عَنْ أَبِيهِ، عَنْ عُمَارَةَ بْنِ الْقَعْقَاعِ، عَنْ أَبِي زُرْعَةَ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ اللَّهُمَّ اجْعَلْ رِزْقَ آلِ مُحَمَّدٍ قُوتًا ‏"‏ ‏.‏\hadithno{7440}\hadithtrans{Abu Huraira reported Allah's Messenger (ﷺ) as saying:O Allah, make for the family of Muhammad the provision which is a bare subsistence}}
\hadithdefcmd{muslim}{7441}{وَحَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، وَعَمْرٌو النَّاقِدُ، وَزُهَيْرُ بْنُ حَرْبٍ، وَأَبُو كُرَيْبٍ قَالُوا حَدَّثَنَا وَكِيعٌ، حَدَّثَنَا الأَعْمَشُ، عَنْ عُمَارَةَ بْنِ الْقَعْقَاعِ، عَنْ أَبِي زُرْعَةَ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ اللَّهُمَّ اجْعَلْ رِزْقَ آلِ مُحَمَّدٍ قُوتًا ‏"‏ ‏.‏ وَفِي رِوَايَةِ عَمْرٍو ‏"‏ اللَّهُمَّ ارْزُقْ ‏"‏ ‏.‏\hadithno{7441}\hadithtrans{Abu Huraira reported Allah's Messenger (ﷺ) as saying:0 Allah, provide for the, family of Muhammad their subsistence, and in the narration transmitted on the authority of 'Amr (the words are):" O Allah, provide us subsistence}}
\hadithdefcmd{muslim}{7442}{وَحَدَّثَنَاهُ أَبُو سَعِيدٍ الأَشَجُّ، حَدَّثَنَا أَبُو أُسَامَةَ، قَالَ سَمِعْتُ الأَعْمَشَ، ذَكَرَ عَنْ عُمَارَةَ، بْنِ الْقَعْقَاعِ بِهَذَا الإِسْنَادِ وَقَالَ ‏ "‏ كَفَافًا ‏"‏ ‏.‏\hadithno{7442}\hadithtrans{Umara b. al-Qa'qa' reported this hadith with the same chain of transmitters but instead of the word" qut" (bare subsistence) there has been used the word" Kafaf" (adequate means to meet the needs)}}
\hadithdefcmd{muslim}{7443}{حَدَّثَنَا زُهَيْرُ بْنُ حَرْبٍ، وَإِسْحَاقُ بْنُ إِبْرَاهِيمَ، قَالَ إِسْحَاقُ أَخْبَرَنَا وَقَالَ، زُهَيْرٌ حَدَّثَنَا جَرِيرٌ، عَنْ مَنْصُورٍ، عَنْ إِبْرَاهِيمَ، عَنِ الأَسْوَدِ، عَنْ عَائِشَةَ، قَالَتْ مَا شَبِعَ آلُ مُحَمَّدٍ صلى الله عليه وسلم مُنْذُ قَدِمَ الْمَدِينَةَ مِنْ طَعَامِ بُرٍّ ثَلاَثَ لَيَالٍ تِبَاعًا حَتَّى قُبِضَ ‏.‏\hadithno{7443}\hadithtrans{A'isha reported:Never had the family of Muhammad (ﷺ) eaten to the fill since their, arrival in Medina with the bread of wheat for three successive nights until his (Holy Prophet's) death}}
\hadithdefcmd{muslim}{7444}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، وَأَبُو كُرَيْبٍ وَإِسْحَاقُ بْنُ إِبْرَاهِيمَ قَالَ إِسْحَاقُ أَخْبَرَنَا وَقَالَ الآخَرَانِ، حَدَّثَنَا أَبُو مُعَاوِيَةَ، عَنِ الأَعْمَشِ، عَنْ إِبْرَاهِيمَ، عَنِ الأَسْوَدِ، عَنْ عَائِشَةَ، قَالَتْ مَا شَبِعَ رَسُولُ اللَّهِ صلى الله عليه وسلم ثَلاَثَةَ أَيَّامٍ تِبَاعًا مِنْ خُبْزِ بُرٍّ حَتَّى مَضَى لِسَبِيلِهِ ‏.‏\hadithno{7444}\hadithtrans{A'isha reported Allah's Messenger (ﷺ) as saying:Never did Allah's Messenger (ﷺ) eat to his fill the bread of wheat for three successive days until he had run the course of his life}}
\hadithdefcmd{muslim}{7445}{حَدَّثَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، وَمُحَمَّدُ بْنُ بَشَّارٍ، قَالاَ حَدَّثَنَا مُحَمَّدُ بْنُ جَعْفَرٍ، حَدَّثَنَا شُعْبَةُ، عَنْ أَبِي إِسْحَاقَ، قَالَ سَمِعْتُ عَبْدَ الرَّحْمَنِ بْنَ يَزِيدَ، يُحَدِّثُ عَنِ الأَسْوَدِ، عَنْ عَائِشَةَ، أَنَّهَا قَالَتْ مَا شَبِعَ آلُ مُحَمَّدٍ صلى الله عليه وسلم مِنْ خُبْزِ شَعِيرٍ يَوْمَيْنِ مُتَتَابِعَيْنِ حَتَّى قُبِضَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏.‏\hadithno{7445}\hadithtrans{A'isha reported:Never did the family of Muhammad (ﷺ) eat to the fill the bread of barley for two successive days until Allah's Messenger (ﷺ) died}}
\hadithdefcmd{muslim}{7446}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا وَكِيعٌ، عَنْ سُفْيَانَ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ عَابِسٍ، عَنْ أَبِيهِ، عَنْ عَائِشَةَ، قَالَتْ مَا شَبِعَ آلُ مُحَمَّدٍ صلى الله عليه وسلم مِنْ خُبْزِ بُرٍّ فَوْقَ ثَلاَثٍ ‏.‏\hadithno{7446}\hadithtrans{A'isha reported:Never could the family of Muhammad (ﷺ) (afford to eat to the fill) the bread of wheat beyond three days (successively)}}
\hadithdefcmd{muslim}{7464}{حَدَّثَنَا يَحْيَى بْنُ أَيُّوبَ، وَقُتَيْبَةُ بْنُ سَعِيدٍ، وَعَلِيُّ بْنُ حُجْرٍ، جَمِيعًا عَنْ إِسْمَاعِيلَ، قَالَ ابْنُ أَيُّوبَ حَدَّثَنَا إِسْمَاعِيلُ بْنُ جَعْفَرٍ، أَخْبَرَنِي عَبْدُ اللَّهِ بْنُ دِينَارٍ، أَنَّهُ سَمِعَ عَبْدَ اللَّهِ، بْنَ عُمَرَ يَقُولُ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم لأَصْحَابِ الْحِجْرِ ‏ "‏ لاَ تَدْخُلُوا عَلَى هَؤُلاَءِ الْقَوْمِ الْمُعَذَّبِينَ إِلاَّ أَنْ تَكُونُوا بَاكِينَ فَإِنْ لَمْ تَكُونُوا بَاكِينَ فَلاَ تَدْخُلُوا عَلَيْهِمْ أَنْ يُصِيبَكُمْ مِثْلُ مَا أَصَابَهُمْ ‏"‏ ‏.‏\hadithno{7464}\hadithtrans{Abdullah b. Umar reported that Allah's Messenger (ﷺ) said in connection with the people of Hijr (Thamud):Do not enter but weepingly (the habitations) of these people who had been punished by (Allah), and in case you do not feel inclined to weep, then do not enter (these habitations) that you may not meet the same calamity as had fallen to their lot}}
\hadithdefcmd{muslim}{7465}{حَدَّثَنِي حَرْمَلَةُ بْنُ يَحْيَى، أَخْبَرَنَا ابْنُ وَهْبٍ، أَخْبَرَنِي يُونُسُ، عَنِ ابْنِ شِهَابٍ، - وَهُوَ يَذْكُرُ الْحِجْرَ مَسَاكِنَ ثَمُودَ - قَالَ سَالِمُ بْنُ عَبْدِ اللَّهِ إِنَّ عَبْدَ اللَّهِ بْنَ عُمَرَ قَالَ مَرَرْنَا مَعَ رَسُولِ اللَّهِ صلى الله عليه وسلم عَلَى الْحِجْرِ فَقَالَ لَنَا رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ لاَ تَدْخُلُوا مَسَاكِنَ الَّذِينَ ظَلَمُوا أَنْفُسَهُمْ إِلاَّ أَنْ تَكُونُوا بَاكِينَ حَذَرًا أَنْ يُصِيبَكُمْ مِثْلُ مَا أَصَابَهُمْ ‏"‏ ‏.‏ ثُمَّ زَجَرَ فَأَسْرَعَ حَتَّى خَلَّفَهَا ‏.‏\hadithno{7465}\hadithtrans{Ibn Shihab reported, and he had been talking about the stony abodes of Thamud, and he said:Salim b. 'Abdullah reported that 'Abdullah b. Umar said: We were passing along with Allah's Messenger (ﷺ) through the habitations of Hijr, and Allah's Messenger (ﷺ) said: Do not enter but weepingly the habitations of these persons who committed tyranny among themselves, lest the same calamity should fall upon you as it fell upon them. He then urged his mount to proceed quickly and pass through that valley hurriedly}}
\hadithdefcmd{muslim}{7466}{حَدَّثَنِي الْحَكَمُ بْنُ مُوسَى أَبُو صَالِحٍ، حَدَّثَنَا شُعَيْبُ بْنُ إِسْحَاقَ، أَخْبَرَنَا عُبَيْدُ اللَّهِ، عَنْ نَافِعٍ، أَنَّ عَبْدَ اللَّهِ بْنَ عُمَرَ، أَخْبَرَهُ أَنَّ النَّاسَ نَزَلُوا مَعَ رَسُولِ اللَّهِ صلى الله عليه وسلم عَلَى الْحِجْرِ أَرْضِ ثَمُودَ فَاسْتَقَوْا مِنْ آبَارِهَا وَعَجَنُوا بِهِ الْعَجِينَ فَأَمَرَهُمْ رَسُولُ اللَّهِ صلى الله عليه وسلم أَنْ يُهَرِيقُوا مَا اسْتَقَوْا وَيَعْلِفُوا الإِبِلَ الْعَجِينَ وَأَمَرَهُمْ أَنْ يَسْتَقُوا مِنَ الْبِئْرِ الَّتِي كَانَتْ تَرِدُهَا النَّاقَةُ ‏.‏\hadithno{7466}\hadithtrans{Abdullah b. 'Umar reported that the people encamped along with Allah's Messenger (ﷺ) in the valley of Hijr, the habitations of Thamud, and they quenched their thirst from the wells thereof and kneaded the flour with it. Thereupon Allah's Messenger (ﷺ) commanded that the water collected for drinking should be spilt and the flour should be given to the camels and commanded them that the water for drinking should be taken from that well where the she-camel (of Hadrat Salih) used to come}}
\hadithdefcmd{muslim}{7467}{وَحَدَّثَنَا إِسْحَاقُ بْنُ مُوسَى الأَنْصَارِيُّ، حَدَّثَنَا أَنَسُ بْنُ عِيَاضٍ، حَدَّثَنِي عُبَيْدُ اللَّهِ، بِهَذَا الإِسْنَادِ ‏.‏ مِثْلَهُ غَيْرَ أَنَّهُ قَالَ فَاسْتَقَوْا مِنْ بِئَارِهَا وَاعْتَجَنُوا بِهِ ‏.‏\hadithno{7467}\hadithtrans{This hadith has been narrated on the authority of 'Abdullah with the same chain of transmitters but with a slight variation of wording}}
\hadithdefcmd{muslim}{7468}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ مَسْلَمَةَ بْنِ قَعْنَبٍ، حَدَّثَنَا مَالِكٌ، عَنْ ثَوْرِ بْنِ زَيْدٍ، عَنْ أَبِي الْغَيْثِ، عَنْ أَبِي هُرَيْرَةَ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ السَّاعِي عَلَى الأَرْمَلَةِ وَالْمِسْكِينِ كَالْمُجَاهِدِ فِي سَبِيلِ اللَّهِ - وَأَحْسِبُهُ قَالَ - وَكَالْقَائِمِ لاَ يَفْتُرُ وَكَالصَّائِمِ لاَ يُفْطِرُ ‏"‏ ‏.‏\hadithno{7468}\hadithtrans{Abu Huraira reported that Allah's Messenger (ﷺ) said:One who makes efforts (for earning to be spent) on a widow and the destitute is like a striver in the cause of Allah, and I think he also said: He is like one who constantly stands for prayer and observes fast without breaking it}}
\hadithdefcmd{muslim}{7469}{حَدَّثَنِي زُهَيْرُ بْنُ حَرْبٍ، حَدَّثَنَا إِسْحَاقُ بْنُ عِيسَى، حَدَّثَنَا مَالِكٌ، عَنْ ثَوْرِ بْنِ زَيْدٍ، الدِّيلِيِّ قَالَ سَمِعْتُ أَبَا الْغَيْثِ، يُحَدِّثُ عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ كَافِلُ الْيَتِيمِ لَهُ أَوْ لِغَيْرِهِ أَنَا وَهُوَ كَهَاتَيْنِ فِي الْجَنَّةِ ‏"‏ ‏.‏ وَأَشَارَ مَالِكٌ بِالسَّبَّابَةِ وَالْوُسْطَى ‏.‏\hadithno{7469}\hadithtrans{Abu Huraira reported that Allah's Messenger (ﷺ) said:One who looks after the orphan whether he is his relative or not, I and he would be together in Paradise like this, and Malik (explained it) with the gesture by drawing his index finger and middle finger close together}}
\hadithdefcmd{muslim}{7470}{حَدَّثَنِي هَارُونُ بْنُ سَعِيدٍ الأَيْلِيُّ، وَأَحْمَدُ بْنُ عِيسَى، قَالاَ حَدَّثَنَا ابْنُ وَهْبٍ، أَخْبَرَنِي عَمْرٌو، - وَهُوَ ابْنُ الْحَارِثِ - أَنَّ بُكَيْرًا، حَدَّثَهُ أَنَّ عَاصِمَ بْنَ عُمَرَ بْنِ قَتَادَةَ حَدَّثَهُ أَنَّهُ، سَمِعَ عُبَيْدَ اللَّهِ الْخَوْلاَنِيَّ، يَذْكُرُ أَنَّهُ سَمِعَ عُثْمَانَ بْنَ عَفَّانَ، عِنْدَ قَوْلِ النَّاسِ فِيهِ حِينَ بَنَى مَسْجِدَ رَسُولِ اللَّهِ صلى الله عليه وسلم إِنَّكُمْ قَدْ أَكْثَرْتُمْ وَإِنِّي سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏"‏ مَنْ بَنَى مَسْجِدًا - قَالَ بُكَيْرٌ حَسِبْتُ أَنَّهُ قَالَ - يَبْتَغِي بِهِ وَجْهَ اللَّهِ بَنَى اللَّهُ لَهُ مِثْلَهُ فِي الْجَنَّةِ ‏"‏ ‏.‏ وَفِي رِوَايَةِ هَارُونَ ‏"‏ بَنَى اللَّهُ لَهُ بَيْتًا فِي الْجَنَّةِ ‏"‏ ‏.‏\hadithno{7470}\hadithtrans{Abdullah al-Khaulani reported that when Uthman b. 'Affan tried to rebuild the mosque of Allah's Messenger (ﷺ) the people began to talk about this. Uthman b. 'Affan said:You discuss it very much whereas I have heard Allah's Messenger (ﷺ) as saying: He who builds a mosque-- and the narrator Bukair said: I think he also said: (for) seeking the pleasure of Allah- Allah would build (a similar house for him in Paradise). and in the narration of Harun (the words are):" A house for him in Paradise}}
\hadithdefcmd{muslim}{7471}{حَدَّثَنَا زُهَيْرُ بْنُ حَرْبٍ، وَمُحَمَّدُ بْنُ الْمُثَنَّى، كِلاَهُمَا عَنِ الضَّحَّاكِ، - قَالَ ابْنُ الْمُثَنَّى حَدَّثَنَا الضَّحَّاكُ بْنُ مَخْلَدٍ، - أَخْبَرَنَا عَبْدُ الْحَمِيدِ بْنُ جَعْفَرٍ، حَدَّثَنِي أَبِي، عَنْ مَحْمُودِ بْنِ لَبِيدٍ، أَنَّ عُثْمَانَ بْنَ عَفَّانَ، أَرَادَ بِنَاءَ الْمَسْجِدِ فَكَرِهَ النَّاسُ ذَلِكَ وَأَحَبُّوا أَنْ يَدَعَهُ عَلَى هَيْئَتِهِ فَقَالَ سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏ "‏ مَنْ بَنَى مَسْجِدًا لِلَّهِ بَنَى اللَّهُ لَهُ فِي الْجَنَّةِ مِثْلَهُ ‏"‏ ‏.‏\hadithno{7471}\hadithtrans{Mahmud b. Labid reported that 'Uthman b. 'Affan decided to rebuild the mosque (of Allah's Apostle in Medina) but the people did not like this idea and they wished that it should be preserved in the same (old) form. Thereupon he (Hadrat 'Uthman) said:I heard Allah's Messenger (ﷺ) as saying: He who builds a mosque for Allah, Allah would build for him (a house) in Paradise like it}}
\hadithdefcmd{muslim}{7472}{وَحَدَّثَنَاهُ إِسْحَاقُ بْنُ إِبْرَاهِيمَ الْحَنْظَلِيُّ، حَدَّثَنَا أَبُو بَكْرٍ الْحَنَفِيُّ، وَعَبْدُ الْمَلِكِ بْنُ، الصَّبَّاحِ كِلاَهُمَا عَنْ عَبْدِ الْحَمِيدِ بْنِ جَعْفَرٍ، بِهَذَا الإِسْنَادِ غَيْرَ أَنَّ فِي، حَدِيثِهِمَا ‏ "‏ بَنَى اللَّهُ لَهُ بَيْتًا فِي الْجَنَّةِ ‏"‏ ‏.‏\hadithno{7472}\hadithtrans{This hadith has been narrated on the authority of Ja'far with the same chain of transmitters with this variation (that the words are):" Allah would build for him a house in Paradise}}
\hadithdefcmd{muslim}{7473}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، وَزُهَيْرُ بْنُ حَرْبٍ، - وَاللَّفْظُ لأَبِي بَكْرٍ - قَالاَ حَدَّثَنَا يَزِيدُ بْنُ هَارُونَ، حَدَّثَنَا عَبْدُ الْعَزِيزِ بْنُ أَبِي سَلَمَةَ، عَنْ وَهْبِ بْنِ كَيْسَانَ، عَنْ عُبَيْدِ بْنِ عُمَيْرٍ، اللَّيْثِيِّ عَنْ أَبِي هُرَيْرَةَ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ بَيْنَا رَجُلٌ بِفَلاَةٍ مِنَ الأَرْضِ فَسَمِعَ صَوْتًا فِي سَحَابَةٍ اسْقِ حَدِيقَةَ فُلاَنٍ ‏.‏ فَتَنَحَّى ذَلِكَ السَّحَابُ فَأَفْرَغَ مَاءَهُ فِي حَرَّةٍ فَإِذَا شَرْجَةٌ مِنْ تِلْكَ الشِّرَاجِ قَدِ اسْتَوْعَبَتْ ذَلِكَ الْمَاءَ كُلَّهُ فَتَتَبَّعَ الْمَاءَ فَإِذَا رَجُلٌ قَائِمٌ فِي حَدِيقَتِهِ يُحَوِّلُ الْمَاءَ بِمِسْحَاتِهِ فَقَالَ لَهُ يَا عَبْدَ اللَّهِ مَا اسْمُكَ قَالَ فُلاَنٌ ‏.‏ لِلاِسْمِ الَّذِي سَمِعَ فِي السَّحَابَةِ فَقَالَ لَهُ يَا عَبْدَ اللَّهِ لِمَ تَسْأَلُنِي عَنِ اسْمِي فَقَالَ إِنِّي سَمِعْتُ صَوْتًا فِي السَّحَابِ الَّذِي هَذَا مَاؤُهُ يَقُولُ اسْقِ حَدِيقَةَ فُلاَنٍ لاِسْمِكَ فَمَا تَصْنَعُ فِيهَا قَالَ أَمَّا إِذَا قُلْتَ هَذَا فَإِنِّي أَنْظُرُ إِلَى مَا يَخْرُجُ مِنْهَا فَأَتَصَدَّقُ بِثُلُثِهِ وَآكُلُ أَنَا وَعِيَالِي ثُلُثًا وَأَرُدُّ فِيهَا ثُلُثَهُ ‏"‏ ‏.‏\hadithno{7473}\hadithtrans{Abu Huraira reported:While a person was in the wilderness he heard a voice from the cloud (commanding it thus): Irrigate the garden of so and so. (After that the clouds slinked aside and poured water on a stony ground. It filled a channel amongst the channels of that land and that person followed that water and he found a person standing in the garden busy in changing the course of water with the help of a hatchet. He said to him: Servant of Allah, what is your name? he said: So and so. And it was that very name which he had heard from the clouds. and he said to him: Servant of Allah, why do you ask me my name? He said: I heard a voice from the clouds of which is the downpour, saying: Water the garden of so and so, like your name. What do you do (for the favour) shown to you by Allah in this matter? He said: Now as you state so. I look what yield I get from it, and I give one-third as charity out of it and I and my children eat one-third of it and one-third I return to it as investment}}
\hadithdefcmd{muslim}{7474}{وَحَدَّثَنَاهُ أَحْمَدُ بْنُ عَبْدَةَ الضَّبِّيُّ، أَخْبَرَنَا أَبُو دَاوُدَ، حَدَّثَنَا عَبْدُ الْعَزِيزِ بْنُ أَبِي سَلَمَةَ، حَدَّثَنَا وَهْبُ بْنُ كَيْسَانَ، بِهَذَا الإِسْنَادِ غَيْرَ أَنَّهُ قَالَ ‏ "‏ وَأَجْعَلُ ثُلُثَهُ فِي الْمَسَاكِينِ وَالسَّائِلِينَ وَابْنِ السَّبِيلِ ‏"‏ ‏.‏\hadithno{7474}\hadithtrans{This hadith has been narrated on the authority of Wahb b. Kaisan with the same chain of transmitters but with this change that he said:" I earmark one-third for the poor, the needy and the wayfarers}}
\hadithdefcmd{muslim}{7475}{حَدَّثَنِي زُهَيْرُ بْنُ حَرْبٍ، حَدَّثَنَا إِسْمَاعِيلُ بْنُ إِبْرَاهِيمَ، أَخْبَرَنَا رَوْحُ بْنُ الْقَاسِمِ، عَنِ الْعَلاَءِ بْنِ عَبْدِ الرَّحْمَنِ بْنِ يَعْقُوبَ، عَنْ أَبِيهِ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ قَالَ اللَّهُ تَبَارَكَ وَتَعَالَى أَنَا أَغْنَى الشُّرَكَاءِ عَنِ الشِّرْكِ مَنْ عَمِلَ عَمَلاً أَشْرَكَ فِيهِ مَعِي غَيْرِي تَرَكْتُهُ وَشِرْكَهُ ‏"‏ ‏.‏\hadithno{7475}\hadithtrans{Abu Huraira reported Allah's Messenger (ﷺ) as stating that Allah the Most High and Exalted said:I am the One, One Who does not stand in need of a partner. If anyone does anything in which he associates anyone else with Me, I shall abandon him with one whom he associates with Allah}}
\hadithdefcmd{muslim}{7476}{حَدَّثَنَا عُمَرُ بْنُ حَفْصِ بْنِ غِيَاثٍ، حَدَّثَنِي أَبِي، عَنْ إِسْمَاعِيلَ بْنِ سُمَيْعٍ، عَنْ مُسْلِمٍ، الْبَطِينِ عَنْ سَعِيدِ بْنِ جُبَيْرٍ، عَنِ ابْنِ عَبَّاسٍ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ مَنْ سَمَّعَ سَمَّعَ اللَّهُ بِهِ وَمَنْ رَاءَى رَاءَى اللَّهُ بِهِ ‏"‏ ‏.‏\hadithno{7476}\hadithtrans{Ibn Abbas reported Allah's Messenger (ﷺ) as saying:If anyone wants to have his deeds widely publicised, Allah will publicise (his humiliation). And if anyone makes a hypocritical display (of his deeds) Allah will make a display of him}}
\hadithdefcmd{muslim}{7477}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا وَكِيعٌ، عَنْ سُفْيَانَ، عَنْ سَلَمَةَ بْنِ كُهَيْلٍ، قَالَ سَمِعْتُ جُنْدُبًا الْعَلَقِيَّ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ مَنْ يُسَمِّعْ يُسَمِّعِ اللَّهُ بِهِ وَمَنْ يُرَائِي يُرَائِي اللَّهُ بِهِ ‏"‏ ‏.‏\hadithno{7477}\hadithtrans{Jundub reported Allah's Messenger (ﷺ) as saying:He who wants to publicise (his deeds), Allah will publicise (his humility), and he who makes a hypocritical display (of his deeds), Allah will make a display of him}}
\hadithdefcmd{muslim}{7478}{وَحَدَّثَنَا إِسْحَاقُ بْنُ إِبْرَاهِيمَ، حَدَّثَنَا الْمُلاَئِيُّ، حَدَّثَنَا سُفْيَانُ، بِهَذَا الإِسْنَادِ وَزَادَ وَلَمْ أَسْمَعْ أَحَدًا غَيْرَهُ يَقُولُ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏.‏\hadithno{7478}\hadithtrans{Sufyan reported this hadith with the same chain of transmitters and he made this addition:" I did not hear anyone saying besides him that it was Allah's Messenger (ﷺ) who had said so}}
\hadithdefcmd{muslim}{7479}{حَدَّثَنَا سَعِيدُ بْنُ عَمْرٍو الأَشْعَثِيُّ، أَخْبَرَنَا سُفْيَانُ، عَنِ الْوَلِيدِ بْنِ حَرْبٍ، - قَالَ سَعِيدٌ أَظُنُّهُ قَالَ ابْنُ الْحَارِثِ بْنِ أَبِي مُوسَى - قَالَ سَمِعْتُ سَلَمَةَ بْنَ كُهَيْلٍ، قَالَ سَمِعْتُ جُنْدُبًا، - وَلَمْ أَسْمَعْ أَحَدًا يَقُولُ سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم غَيْرَهُ - يَقُولُ سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ بِمِثْلِ حَدِيثِ الثَّوْرِيِّ ‏.‏\hadithno{7479}\hadithtrans{Salama b. Kuhail reported:I heard from Jundub, but I did not hear him say this: "I heard Allah's Messenger (ﷺ) saying this}}
\hadithdefcmd{muslim}{7480}{وَحَدَّثَنَاهُ ابْنُ أَبِي عُمَرَ، حَدَّثَنَا سُفْيَانُ، حَدَّثَنَا الصَّدُوقُ الأَمِينُ الْوَلِيدُ بْنُ حَرْبٍ، بِهَذَا الإِسْنَادِ ‏.‏\hadithno{7480}\hadithtrans{Abu Sufyan reported like that as as-Saduq al-Amin al-Walid b. Harb narrated with the same chain of transmitters}}
\hadithdefcmd{muslim}{7481}{حَدَّثَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، حَدَّثَنَا بَكْرٌ، - يَعْنِي ابْنَ مُضَرَ - عَنِ ابْنِ الْهَادِ، عَنْ مُحَمَّدِ، بْنِ إِبْرَاهِيمَ عَنْ عِيسَى بْنِ طَلْحَةَ، عَنْ أَبِي هُرَيْرَةَ، أَنَّهُ سَمِعَ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏ "‏ إِنَّ الْعَبْدَ لَيَتَكَلَّمُ بِالْكَلِمَةِ يَنْزِلُ بِهَا فِي النَّارِ أَبْعَدَ مَا بَيْنَ الْمَشْرِقِ وَالْمَغْرِبِ ‏"‏ ‏.‏\hadithno{7481}\hadithtrans{Abu Huraira reported that he heard Allah's Messenger (ﷺ) as saying:The servant speaks words for which he is sent down to the Hell-Fire farther than the distance between the east and the west}}
\hadithdefcmd{muslim}{7482}{وَحَدَّثَنَاهُ مُحَمَّدُ بْنُ أَبِي عُمَرَ الْمَكِّيُّ، حَدَّثَنَا عَبْدُ الْعَزِيزِ الدَّرَاوَرْدِيُّ، عَنْ يَزِيدَ بْنِ، الْهَادِ عَنْ مُحَمَّدِ بْنِ إِبْرَاهِيمَ، عَنْ عِيسَى بْنِ طَلْحَةَ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ إِنَّ الْعَبْدَ لَيَتَكَلَّمُ بِالْكَلِمَةِ مَا يَتَبَيَّنُ مَا فِيهَا يَهْوِي بِهَا فِي النَّارِ أَبْعَدَ مَا بَيْنَ الْمَشْرِقِ وَالْمَغْرِبِ ‏"‏ ‏.‏\hadithno{7482}\hadithtrans{Abu Huraira reported Allah's Messenger (ﷺ) as saying:The servant speaks words that he does not understand its repercussions but he sinks down in Hell-Fire farther than the distance between the east and the west}}
\hadithdefcmd{muslim}{7483}{حَدَّثَنَا يَحْيَى بْنُ يَحْيَى، وَأَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ وَمُحَمَّدُ بْنُ عَبْدِ اللَّهِ بْنِ نُمَيْرٍ وَإِسْحَاقُ بْنُ إِبْرَاهِيمَ وَأَبُو كُرَيْبٍ - وَاللَّفْظُ لأَبِي كُرَيْبٍ - قَالَ يَحْيَى وَإِسْحَاقُ أَخْبَرَنَا وَقَالَ الآخَرُونَ حَدَّثَنَا أَبُو مُعَاوِيَةَ حَدَّثَنَا الأَعْمَشُ عَنْ شَقِيقٍ عَنْ أُسَامَةَ بْنِ زَيْدٍ قَالَ قِيلَ لَهُ أَلاَ تَدْخُلُ عَلَى عُثْمَانَ فَتُكَلِّمَهُ فَقَالَ أَتُرَوْنَ أَنِّي لاَ أُكَلِّمُهُ إِلاَّ أُسْمِعُكُمْ وَاللَّهِ لَقَدْ كَلَّمْتُهُ فِيمَا بَيْنِي وَبَيْنَهُ مَا دُونَ أَنْ أَفْتَتِحَ أَمْرًا لاَ أُحِبُّ أَنْ أَكُونَ أَوَّلَ مَنْ فَتَحَهُ وَلاَ أَقُولُ لأَحَدٍ يَكُونُ عَلَىَّ أَمِيرًا إِنَّهُ خَيْرُ النَّاسِ ‏.‏ بَعْدَ مَا سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏ "‏ يُؤْتَى بِالرَّجُلِ يَوْمَ الْقِيَامَةِ فَيُلْقَى فِي النَّارِ فَتَنْدَلِقُ أَقْتَابُ بَطْنِهِ فَيَدُورُ بِهَا كَمَا يَدُورُ الْحِمَارُ بِالرَّحَى فَيَجْتَمِعُ إِلَيْهِ أَهْلُ النَّارِ فَيَقُولُونَ يَا فُلاَنُ مَا لَكَ أَلَمْ تَكُنْ تَأْمُرُ بِالْمَعْرُوفِ وَتَنْهَى عَنِ الْمُنْكَرِ فَيَقُولُ بَلَى قَدْ كُنْتُ آمُرُ بِالْمَعْرُوفِ وَلاَ آتِيهِ وَأَنْهَى عَنِ الْمُنْكَرِ وَآتِيهِ ‏"‏ ‏.‏\hadithno{7483}\hadithtrans{Shaqiq reported that it was said to Usama b. Zaid:Why don't you visit 'Uthman and talk to him? Thereupon he said: Do you think that I have not talked to him but that I have made you hear? By Allah. I have talked to him (about things) concerning me and him and I did not like to divulge those things about which I had to take the initiative and I do not say to my ruler: "You are the best among people," after I heard Allah's Messenger (ﷺ) as saying: A man will be brought on the Day of Resurrection and thrown in Hell-Fire and his intestines will pour forth in Hell and he will go round along with them, as an ass goes round the mill stone. The denizens of Hell would gather round him and say: O, so and so, what has happened to you? Were you not enjoining us to do what was reputable and forbid us to do what was disreputable? He will say: Of course, it is so; I used to enjoin (upon people) to do what was reputable but did not practise that myself. I had been forbidding people to do what was disreputable, but practised it myself}}
\hadithdefcmd{muslim}{7484}{حَدَّثَنَا عُثْمَانُ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا جَرِيرٌ، عَنِ الأَعْمَشِ، عَنْ أَبِي وَائِلٍ، قَالَ كُنَّا عِنْدَ أُسَامَةَ بْنِ زَيْدٍ فَقَالَ رَجُلٌ مَا يَمْنَعُكَ أَنْ تَدْخُلَ عَلَى عُثْمَانَ فَتُكَلِّمَهُ فِيمَا يَصْنَعُ وَسَاقَ الْحَدِيثَ بِمِثْلِهِ ‏.‏\hadithno{7484}\hadithtrans{Abu Wa'il reported:I was in the company of Usama b. Zaid that a person said: What prevents you to visit Uthman and talk to him for what he does? The rest of the hadith is the same}}
\hadithdefcmd{muslim}{7485}{حَدَّثَنِي زُهَيْرُ بْنُ حَرْبٍ، وَمُحَمَّدُ بْنُ حَاتِمٍ، وَعَبْدُ بْنُ حُمَيْدٍ، قَالَ عَبْدٌ حَدَّثَنِي وَقَالَ، الآخَرَانِ حَدَّثَنَا يَعْقُوبُ بْنُ إِبْرَاهِيمَ، حَدَّثَنَا ابْنُ أَخِي ابْنِ شِهَابٍ، عَنْ عَمِّهِ، قَالَ قَالَ سَالِمٌ سَمِعْتُ أَبَا هُرَيْرَةَ، يَقُولُ سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏"‏ كُلُّ أُمَّتِي مُعَافَاةٌ إِلاَّ الْمُجَاهِرِينَ وَإِنَّ مِنَ الإِجْهَارِ أَنْ يَعْمَلَ الْعَبْدُ بِاللَّيْلِ عَمَلاً ثُمَّ يُصْبِحُ قَدْ سَتَرَهُ رَبُّهُ فَيَقُولُ يَا فُلاَنُ قَدْ عَمِلْتُ الْبَارِحَةَ كَذَا وَكَذَا وَقَدْ بَاتَ يَسْتُرُهُ رَبُّهُ فَيَبِيتُ يَسْتُرُهُ رَبُّهُ وَيُصْبِحُ يَكْشِفُ سِتْرَ اللَّهِ عَنْهُ ‏"‏ ‏.‏ قَالَ زُهَيْرٌ ‏"‏ وَإِنَّ مِنَ الْهِجَارِ ‏"‏ ‏.‏\hadithno{7485}\hadithtrans{Abu Huraira reported Allah's Messenger (ﷺ) as saying:All the people of my Ummah would get pardon for their sins except those who publicise them. And (it means) that a servant should do a deed during the night and tell the people in the morning that he has done so and so, whereas Allah has concealed it. And he does a deed during the day and when it is night he tells the people, whereas Allah has concealed it. Zuhair has used the word hijar for publicising}}
\hadithdefcmd{muslim}{7486}{حَدَّثَنِي مُحَمَّدُ بْنُ عَبْدِ اللَّهِ بْنِ نُمَيْرٍ، حَدَّثَنَا حَفْصٌ، - وَهُوَ ابْنُ غِيَاثٍ - عَنْ سُلَيْمَانَ، التَّيْمِيِّ عَنْ أَنَسِ بْنِ مَالِكٍ، قَالَ عَطَسَ عِنْدَ النَّبِيِّ صلى الله عليه وسلم رَجُلاَنِ فَشَمَّتَ أَحَدَهُمَا وَلَمْ يُشَمِّتِ الآخَرَ فَقَالَ الَّذِي لَمْ يُشَمِّتْهُ عَطَسَ فُلاَنٌ فَشَمَّتَّهُ وَعَطَسْتُ أَنَا فَلَمْ تُشَمِّتْنِي ‏.‏ قَالَ ‏ "‏ إِنَّ هَذَا حَمِدَ اللَّهَ وَإِنَّكَ لَمْ تَحْمَدِ اللَّهَ ‏"‏ ‏.‏\hadithno{7486}\hadithtrans{Anas b. Malik reported that two persons sneezed in the presence of Allah's Messenger (ﷺ). He (the Messenger of Allah) invoked mercy for one, and did not invoke for the other. The one for whom he had not prayed said:So and so sneezed and you said: May Allah have mercy upon you. I also sneezed but you did not utter these words for me. Thereupon he (the Holy Prophet) said: That person praised Allah, and you did not praise Allah}}
\hadithdefcmd{muslim}{7487}{وَحَدَّثَنَا أَبُو كُرَيْبٍ، حَدَّثَنَا أَبُو خَالِدٍ، - يَعْنِي الأَحْمَرَ - عَنْ سُلَيْمَانَ التَّيْمِيِّ، عَنْ أَنَسٍ، عَنِ النَّبِيِّ صلى الله عليه وسلم بِمِثْلِهِ ‏.‏\hadithno{7487}\hadithtrans{This hadith has been narrated on the authority of Anas through another chain of transmitters}}
\hadithdefcmd{muslim}{7488}{حَدَّثَنِي زُهَيْرُ بْنُ حَرْبٍ، وَمُحَمَّدُ بْنُ عَبْدِ اللَّهِ بْنِ نُمَيْرٍ، - وَاللَّفْظُ لِزُهَيْرٍ - قَالاَ حَدَّثَنَا الْقَاسِمُ بْنُ مَالِكٍ، عَنْ عَاصِمِ بْنِ كُلَيْبٍ، عَنْ أَبِي بُرْدَةَ، قَالَ دَخَلْتُ عَلَى أَبِي مُوسَى وَهْوَ فِي بَيْتِ بِنْتِ الْفَضْلِ بْنِ عَبَّاسٍ فَعَطَسْتُ فَلَمْ يُشَمِّتْنِي وَعَطَسَتْ فَشَمَّتَهَا فَرَجَعْتُ إِلَى أُمِّي فَأَخْبَرْتُهَا فَلَمَّا جَاءَهَا قَالَتْ عَطَسَ عِنْدَكَ ابْنِي فَلَمْ تُشَمِّتْهُ وَعَطَسَتْ فَشَمَّتَّهَا ‏.‏ فَقَالَ إِنَّ ابْنَكِ عَطَسَ فَلَمْ يَحْمَدِ اللَّهَ فَلَمْ أُشَمِّتْهُ وَعَطَسَتْ فَحَمِدَتِ اللَّهَ فَشَمَّتُّهَا سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏ "‏ إِذَا عَطَسَ أَحَدُكُمْ فَحَمِدَ اللَّهَ فَشَمِّتُوهُ فَإِنْ لَمْ يَحْمَدِ اللَّهَ فَلاَ تُشَمِّتُوهُ ‏"‏ ‏.‏\hadithno{7488}\hadithtrans{Abu Burda reported:I visited Abu Musa, as he was in the house of the daughter of Fadl b. 'Abbas. I sneezed but he did not respond to it (by saying): Allah may have mercy upon you. Then she sneezed and he (Fadl b. 'Abbas) said: May Allah have mercy upon you. I came back to my mother and informed her about it, and when he came to her she said: My son sneezed in your presence and you did not say:" Allah may have mercy upon you, and she sneezed and you said for her:" May Allah have mercy upon you." Thereupon he said: Your son sneezed but he did not praise Allah and I did not beg mercy of Allah for him and she sneezed and she praised Allah and so I said: May Allah have mercy upon you, as I heard Allah's Messenger (ﷺ) as saying: When any one of you sneezes he should praise Allah and the other should say: May Allah have mercy upon you, and if he does not praise Allah, no mercy should be begged for him}}
\hadithdefcmd{muslim}{7489}{حَدَّثَنَا مُحَمَّدُ بْنُ عَبْدِ اللَّهِ بْنِ نُمَيْرٍ، حَدَّثَنَا وَكِيعٌ، حَدَّثَنَا عِكْرِمَةُ بْنُ عَمَّارٍ، عَنْ إِيَاسِ، بْنِ سَلَمَةَ بْنِ الأَكْوَعِ عَنْ أَبِيهِ، ح وَحَدَّثَنَا إِسْحَاقُ بْنُ إِبْرَاهِيمَ، - وَاللَّفْظُ لَهُ - حَدَّثَنَا أَبُو النَّضْرِ، هَاشِمُ بْنُ الْقَاسِمِ حَدَّثَنَا عِكْرِمَةُ بْنُ عَمَّارٍ، حَدَّثَنِي إِيَاسُ بْنُ سَلَمَةَ بْنِ الأَكْوَعِ، أَنَّ أَبَاهُ، حَدَّثَهُ أَنَّهُ، سَمِعَ النَّبِيَّ صلى الله عليه وسلم وَعَطَسَ رَجُلٌ عِنْدَهُ فَقَالَ لَهُ ‏"‏ يَرْحَمُكَ اللَّهُ ‏"‏ ‏.‏ ثُمَّ عَطَسَ أُخْرَى فَقَالَ لَهُ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ الرَّجُلُ مَزْكُومٌ ‏"‏ ‏.‏\hadithno{7489}\hadithtrans{Iyas b. Salama b. al-Akwa reported that his father reported to him that he heard Allah's Apostle (ﷺ) as saying:A person sneezed in his presence and he said to him: May Allah have mercy upon you. And he then sneezed for the second time and Allah's Messenger (ﷺ) said to him: He is suffering from cold (and no response is necessary)}}
\hadithdefcmd{muslim}{7490}{حَدَّثَنَا يَحْيَى بْنُ أَيُّوبَ، وَقُتَيْبَةُ بْنُ سَعِيدٍ، وَعَلِيُّ بْنُ حُجْرٍ السَّعْدِيُّ، قَالُوا حَدَّثَنَا إِسْمَاعِيلُ، - يَعْنُونَ ابْنَ جَعْفَرٍ - عَنِ الْعَلاَءِ، عَنْ أَبِيهِ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ التَّثَاؤُبُ مِنَ الشَّيْطَانِ فَإِذَا تَثَاءَبَ أَحَدُكُمْ فَلْيَكْظِمْ مَا اسْتَطَاعَ ‏"‏ ‏.‏\hadithno{7490}\hadithtrans{Abu Huraira reported Allah's Messenger (ﷺ) as saying:The yawning as from the devil. So when one of you yawns he should try to restrain it as far as it lies in his power}}
\hadithdefcmd{muslim}{7491}{حَدَّثَنِي أَبُو غَسَّانَ الْمِسْمَعِيُّ، مَالِكُ بْنُ عَبْدِ الْوَاحِدِ حَدَّثَنَا بِشْرُ بْنُ الْمُفَضَّلِ، حَدَّثَنَا سُهَيْلُ بْنُ أَبِي صَالِحٍ، قَالَ سَمِعْتُ ابْنًا، لأَبِي سَعِيدٍ الْخُدْرِيِّ يُحَدِّثُ أَبِي عَنْ أَبِيهِ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ إِذَا تَثَاوَبَ أَحَدُكُمْ فَلْيُمْسِكْ بِيَدِهِ عَلَى فِيهِ فَإِنَّ الشَّيْطَانَ يَدْخُلُ ‏"‏ ‏.‏\hadithno{7491}\hadithtrans{The son of Abu Said al-Khudri reported on the authority of his father that Allah's Messenger (ﷺ) said:When one of you yawns, he should keep his mouth shut with the help of his hand, for it is the devil that enters therein}}
\hadithdefcmd{muslim}{7492}{حَدَّثَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، حَدَّثَنَا عَبْدُ الْعَزِيزِ، عَنْ سُهَيْلٍ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ أَبِي، سَعِيدٍ عَنْ أَبِيهِ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ إِذَا تَثَاوَبَ أَحَدُكُمْ فَلْيُمْسِكْ بِيَدِهِ فَإِنَّ الشَّيْطَانَ يَدْخُلُ ‏"‏ ‏.‏\hadithno{7492}\hadithtrans{The son of Abu Said al-Khudri reported on the authority of his father that Allah's Messenger (ﷺ) said:When one of you yawns, he should try to restrain it with cue help of his hand since it is the Satan that enters therein}}
\hadithdefcmd{muslim}{7493}{حَدَّثَنِي أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا وَكِيعٌ، عَنْ سُفْيَانَ، عَنْ سُهَيْلِ بْنِ أَبِي صَالِحٍ، عَنِ ابْنِ أَبِي سَعِيدٍ الْخُدْرِيِّ، عَنْ أَبِيهِ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ إِذَا تَثَاوَبَ أَحَدُكُمْ فِي الصَّلاَةِ فَلْيَكْظِمْ مَا اسْتَطَاعَ فَإِنَّ الشَّيْطَانَ يَدْخُلُ ‏"‏ ‏.‏\hadithno{7493}\hadithtrans{The son of Abu Said al-Khudri reported on the authority of his father that Allah's Messenger (ﷺ) said. When one of you yawns while engaged in prayer, he should try to restrain so far as it lies in his power, since it is the Satan that enter therein}}
\hadithdefcmd{muslim}{7494}{حَدَّثَنَاهُ عُثْمَانُ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا جَرِيرٌ، عَنْ سُهَيْلٍ، عَنْ أَبِيهِ، أَوْ عَنِ ابْنِ أَبِي، سَعِيدٍ عَنْ أَبِي سَعِيدٍ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم بِمِثْلِ حَدِيثِ بِشْرٍ وَعَبْدِ الْعَزِيزِ ‏.‏\hadithno{7494}\hadithtrans{Abu Said al-Khudri reported Allah's Messenger (ﷺ) a hadith like this through another chain of transmitters}}
\hadithdefcmd{muslim}{7495}{حَدَّثَنَا مُحَمَّدُ بْنُ رَافِعٍ، وَعَبْدُ بْنُ حُمَيْدٍ، قَالَ عَبْدٌ أَخْبَرَنَا وَقَالَ ابْنُ رَافِعٍ، حَدَّثَنَا عَبْدُ الرَّزَّاقِ، أَخْبَرَنَا مَعْمَرٌ، عَنِ الزُّهْرِيِّ، عَنْ عُرْوَةَ، عَنْ عَائِشَةَ، قَالَتْ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ خُلِقَتِ الْمَلاَئِكَةُ مِنْ نُورٍ وَخُلِقَ الْجَانُّ مِنْ مَارِجٍ مِنْ نَارٍ وَخُلِقَ آدَمُ مِمَّا وُصِفَ لَكُمْ ‏"‏ ‏.‏\hadithno{7495}\hadithtrans{A'isha reported that Allah's Messenger (ﷺ) said:The Angels were born out of light and the Jinns were born out of the spark of fire and Adam was born as he has been defined (in the Qur'an) for you (i. e. he is fashioned out of clay)}}
\hadithdefcmd{muslim}{7496}{حَدَّثَنَا إِسْحَاقُ بْنُ إِبْرَاهِيمَ، وَمُحَمَّدُ بْنُ الْمُثَنَّى الْعَنَزِيُّ، وَمُحَمَّدُ بْنُ عَبْدِ اللَّهِ الرُّزِّيُّ، جَمِيعًا عَنِ الثَّقَفِيِّ، - وَاللَّفْظُ لاِبْنِ الْمُثَنَّى - حَدَّثَنَا عَبْدُ الْوَهَّابِ، حَدَّثَنَا خَالِدٌ، عَنْ مُحَمَّدِ بْنِ، سِيرِينَ عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ فُقِدَتْ أُمَّةٌ مِنْ بَنِي إِسْرَائِيلَ لاَ يُدْرَى مَا فَعَلَتْ وَلاَ أُرَاهَا إِلاَّ الْفَأْرَ أَلاَ تَرَوْنَهَا إِذَا وُضِعَ لَهَا أَلْبَانُ الإِبِلِ لَمْ تَشْرَبْهُ وَإِذَا وُضِعَ لَهَا أَلْبَانُ الشَّاءِ شَرِبَتْهُ ‏"‏ ‏.‏ قَالَ أَبُو هُرَيْرَةَ فَحَدَّثْتُ هَذَا الْحَدِيثَ كَعْبًا فَقَالَ آنْتَ سَمِعْتَهُ مِنْ رَسُولِ اللَّهِ صلى الله عليه وسلم قُلْتُ نَعَمْ ‏.‏ قَالَ ذَلِكَ مِرَارًا ‏.‏ قُلْتُ أَأَقْرَأُ التَّوْرَاةَ قَالَ إِسْحَاقُ فِي رِوَايَتِهِ ‏"‏ لاَ نَدْرِي مَا فَعَلَتْ ‏"‏ ‏.‏\hadithno{7496}\hadithtrans{Abu Huraira reported that Allah's Messenger (ﷺ) said:A group of Bani Isra'il was lost. I do not know what happened to it, but I think (that it 'underwent a process of metamorphosis) and assumed the shape of rats. Don't you see when the milk of the camel is placed before them, these do not drink and when the milk of goat is placed before them, these do drink. Abu Huraira said: I narrated this very hadith to Ka'b and he said: Did you hear this from Allah's Messenger (ﷺ)? I (Abu Huraira) said: Yes. He said this again and again, and I said: Have I read Torah? This hadith has been transmitted on the authority of Ishaq with a slight variation of wording}}
\hadithdefcmd{muslim}{7497}{وَحَدَّثَنِي أَبُو كُرَيْبٍ، مُحَمَّدُ بْنُ الْعَلاَءِ حَدَّثَنَا أَبُو أُسَامَةَ، عَنْ هِشَامٍ، عَنْ مُحَمَّدٍ، عَنْ أَبِي هُرَيْرَةَ، قَالَ ‏ "‏ الْفَأْرَةُ مَسْخٌ وَآيَةُ ذَلِكَ أَنَّهُ يُوضَعُ بَيْنَ يَدَيْهَا لَبَنُ الْغَنَمِ فَتَشْرَبُهُ وَيُوضَعُ بَيْنَ يَدَيْهَا لَبَنُ الإِبِلِ فَلاَ تَذُوقُهُ ‏"‏ ‏.‏ فَقَالَ لَهُ كَعْبٌ أَسَمِعْتَ هَذَا مِنْ رَسُولِ اللَّهِ صلى الله عليه وسلم قَالَ أَفَأُنْزِلَتْ عَلَىَّ التَّوْرَاةُ\hadithno{7497}\hadithtrans{Abu Huraira reported that the rat (is the result of) metamorphosis (of a group of Bani Isra'il) and the proof of this is that when the milk of goat is placed before it, it drinks it, and when the milk of the camel is placed before it, it would not taste it at all. Ka'b said:Did you hear it from Allah's Messenger (ﷺ)? Thereupon he said: Has Torah been revealed to me?}}
\hadithdefcmd{muslim}{7500}{حَدَّثَنَا هَدَّابُ بْنُ خَالِدٍ الأَزْدِيُّ، وَشَيْبَانُ بْنُ فَرُّوخَ، جَمِيعًا عَنْ سُلَيْمَانَ بْنِ الْمُغِيرَةِ، - وَاللَّفْظُ لِشَيْبَانَ - حَدَّثَنَا سُلَيْمَانُ، حَدَّثَنَا ثَابِتٌ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ أَبِي لَيْلَى، عَنْ صُهَيْبٍ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ عَجَبًا لأَمْرِ الْمُؤْمِنِ إِنَّ أَمْرَهُ كُلَّهُ خَيْرٌ وَلَيْسَ ذَاكَ لأَحَدٍ إِلاَّ لِلْمُؤْمِنِ إِنْ أَصَابَتْهُ سَرَّاءُ شَكَرَ فَكَانَ خَيْرًا لَهُ وَإِنْ أَصَابَتْهُ ضَرَّاءُ صَبَرَ فَكَانَ خَيْرًا لَهُ ‏"‏ ‏.‏\hadithno{7500}\hadithtrans{Suhaib reported that Allah's Messenger (ﷺ) said:Strange are the ways of a believer for there is good in every affair of his and this is not the case with anyone else except in the case of a believer for if he has an occasion to feel delight, he thanks (God), thus there is a good for him in it, and if he gets into trouble and shows resignation (and endures it patiently), there is a good for him in it}}
\hadithdefcmd{muslim}{7501}{حَدَّثَنَا يَحْيَى بْنُ يَحْيَى، حَدَّثَنَا يَزِيدُ بْنُ زُرَيْعٍ، عَنْ خَالِدٍ الْحَذَّاءِ، عَنْ عَبْدِ الرَّحْمَنِ، بْنِ أَبِي بَكْرَةَ عَنْ أَبِيهِ، قَالَ مَدَحَ رَجُلٌ رَجُلاً عِنْدَ النَّبِيِّ صلى الله عليه وسلم - قَالَ - فَقَالَ ‏"‏ وَيْحَكَ قَطَعْتَ عُنُقَ صَاحِبِكَ قَطَعْتَ عُنُقَ صَاحِبِكَ ‏"‏ ‏.‏ مِرَارًا ‏"‏ إِذَا كَانَ أَحَدُكُمْ مَادِحًا صَاحِبَهُ لاَ مَحَالَةَ فَلْيَقُلْ أَحْسِبُ فُلاَنًا وَاللَّهُ حَسِيبُهُ وَلاَ أُزَكِّي عَلَى اللَّهِ أَحَدًا أَحْسِبُهُ إِنْ كَانَ يَعْلَمُ ذَاكَ كَذَا وَكَذَا ‏"‏ ‏.‏\hadithno{7501}\hadithtrans{Abd al-Rahman b. Abu Bakra reported on the authority of his father that a person praised another person in the presence of Allah's Apostle (ﷺ), whereupon he said:Woe be to thee, you have broken the neck of your friend, you have broken the neck of your friend-he said this twice. If one of you has to praise his friend at all, he should say: I think (him to be) so and Allah knows it well and I do not know the secret of the heart and Allah knows the destined end, and I cannot testify his purity against Allah but (he appears) to be so and so}}
\hadithdefcmd{muslim}{7502}{وَحَدَّثَنِي مُحَمَّدُ بْنُ عَمْرِو بْنِ عَبَّادِ بْنِ جَبَلَةَ بْنِ أَبِي رَوَّادٍ، حَدَّثَنَا مُحَمَّدُ بْنُ جَعْفَرٍ، ح وَحَدَّثَنِي أَبُو بَكْرِ بْنُ نَافِعٍ، أَخْبَرَنَا غُنْدَرٌ، قَالَ شُعْبَةُ حَدَّثَنَا عَنْ خَالِدٍ الْحَذَّاءِ، عَنْ عَبْدِ، الرَّحْمَنِ بْنِ أَبِي بَكْرَةَ عَنْ أَبِيهِ، عَنِ النَّبِيِّ صلى الله عليه وسلم أَنَّهُ ذُكِرَ عِنْدَهُ رَجُلٌ فَقَالَ رَجُلٌ يَا رَسُولَ اللَّهِ مَا مِنْ رَجُلٍ بَعْدَ رَسُولِ اللَّهِ صلى الله عليه وسلم أَفْضَلُ مِنْهُ فِي كَذَا وَكَذَا ‏.‏ فَقَالَ النَّبِيُّ صلى الله عليه وسلم ‏"‏ وَيْحَكَ قَطَعْتَ عُنُقَ صَاحِبِكَ ‏"‏ ‏.‏ مِرَارًا يَقُولُ ذَلِكَ ثُمَّ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ إِنْ كَانَ أَحَدُكُمْ مَادِحًا أَخَاهُ لاَ مَحَالَةَ فَلْيَقُلْ أَحْسِبُ فُلاَنًا إِنْ كَانَ يُرَى أَنَّهُ كَذَلِكَ وَلاَ أُزَكِّي عَلَى اللَّهِ أَحَدًا ‏"‏ ‏.‏\hadithno{7502}\hadithtrans{Abd al-Rahman b. Abu Bakra reported on the authority of his father that a person was mentioned in the presence of Allah's Apostle (ﷺ), and a person said:Allah's Messenger, no person is more excellent than he after Allah's Messenger (ﷺ). Thereupon Allah's Apostle (ﷺ) said: Woe be to thee, you have broken the neck of your friend, and he said this twice. Then Allah's Messenger (ﷺ) said: If anyone has to praise his brother at all, he should say: I think him to be so and so, and even on this he should say: I do not consider anyone purer than Allah (considers)}}
\hadithdefcmd{muslim}{7503}{وَحَدَّثَنِيهِ عَمْرٌو النَّاقِدُ، حَدَّثَنَا هَاشِمُ بْنُ الْقَاسِمِ، ح وَحَدَّثَنَاهُ أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا شَبَابَةُ بْنُ سَوَّارٍ، كِلاَهُمَا عَنْ شُعْبَةَ، بِهَذَا الإِسْنَادِ ‏.‏ نَحْوَ حَدِيثِ يَزِيدَ بْنِ زُرَيْعٍ وَلَيْسَ فِي حَدِيثِهِمَا فَقَالَ رَجُلٌ مَا مِنْ رَجُلٍ بَعْدَ رَسُولِ اللَّهِ صلى الله عليه وسلم أَفْضَلُ مِنْهُ ‏.‏\hadithno{7503}\hadithtrans{his hadith has been transmitted on the authority of Shu'ba with a slight variation of wording}}
\hadithdefcmd{muslim}{7504}{حَدَّثَنِي أَبُو جَعْفَرٍ، مُحَمَّدُ بْنُ الصَّبَّاحِ حَدَّثَنَا إِسْمَاعِيلُ بْنُ زَكَرِيَّاءَ، عَنْ بُرَيْدِ بْنِ، عَبْدِ اللَّهِ بْنِ أَبِي بُرْدَةَ عَنْ أَبِي بُرْدَةَ، عَنْ أَبِي مُوسَى، قَالَ سَمِعَ النَّبِيُّ صلى الله عليه وسلم رَجُلاً يُثْنِي عَلَى رَجُلٍ وَيُطْرِيهِ فِي الْمِدْحَةِ فَقَالَ ‏ "‏ لَقَدْ أَهْلَكْتُمْ أَوْ قَطَعْتُمْ ظَهْرَ الرَّجُلِ ‏"‏ ‏.‏\hadithno{7504}\hadithtrans{Abu Musa reported Allah's Messenger (ﷺ) saw a person lauding another person or praising him too much. Thereupon he said:You killed him, or you sliced the back of a person}}
\hadithdefcmd{muslim}{7505}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، وَمُحَمَّدُ بْنُ الْمُثَنَّى، جَمِيعًا عَنِ ابْنِ مَهْدِيٍّ، - وَاللَّفْظُ لاِبْنِ الْمُثَنَّى قَالاَ حَدَّثَنَا عَبْدُ الرَّحْمَنِ، عَنْ سُفْيَانَ، عَنْ حَبِيبٍ، عَنْ مُجَاهِدٍ، عَنْ أَبِي مَعْمَرٍ، قَالَ قَامَ رَجُلٌ يُثْنِي عَلَى أَمِيرٍ مِنَ الأُمَرَاءِ فَجَعَلَ الْمِقْدَادُ يَحْثِي عَلَيْهِ التُّرَابَ وَقَالَ أَمَرَنَا رَسُولُ اللَّهِ صلى الله عليه وسلم أَنْ نَحْثِيَ فِي وُجُوهِ الْمَدَّاحِينَ التُّرَابَ ‏.‏\hadithno{7505}\hadithtrans{Abu Ma'mar reported that a person lauded a ruler amongst the rulers and Miqdad began to throw dust upon him and he said:Allah's Messenger (ﷺ) commanded us that we should throw dust upon the faces of those who shower too much praise}}
\hadithdefcmd{muslim}{7506}{وَحَدَّثَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، وَمُحَمَّدُ بْنُ بَشَّارٍ، - وَاللَّفْظُ لاِبْنِ الْمُثَنَّى - قَالاَ حَدَّثَنَا مُحَمَّدُ بْنُ جَعْفَرٍ، حَدَّثَنَا شُعْبَةُ، عَنْ مَنْصُورٍ، عَنْ إِبْرَاهِيمَ، عَنْ هَمَّامِ بْنِ الْحَارِثِ، أَنَّ رَجُلاً، جَعَلَ يَمْدَحُ عُثْمَانَ فَعَمِدَ الْمِقْدَادُ فَجَثَا عَلَى رُكْبَتَيْهِ - وَكَانَ رَجُلاً ضَخْمًا - فَجَعَلَ يَحْثُو فِي وَجْهِهِ الْحَصْبَاءَ فَقَالَ لَهُ عُثْمَانُ مَا شَأْنُكَ فَقَالَ إِنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ إِذَا رَأَيْتُمُ الْمَدَّاحِينَ فَاحْثُوا فِي وُجُوهِهِمُ التُّرَابَ ‏"‏ ‏.‏\hadithno{7506}\hadithtrans{Hammam b. al-Harith reported that a person began to praise 'Uthman and Miqdad sat upon his knee; and he was a bulky person and began to throw pebbles upon his (flatterer's) face. Thereupon 'Uthman said:What is the matter with you? And he said: Verily, Allah's Messenger (ﷺ) said: When you see those who shower (undue) praise (upon others), throw dust upon their faces}}
\hadithdefcmd{muslim}{7507}{وَحَدَّثَنَاهُ مُحَمَّدُ بْنُ الْمُثَنَّى، وَابْنُ، بَشَّارٍ قَالاَ حَدَّثَنَا عَبْدُ الرَّحْمَنِ، عَنْ سُفْيَانَ، عَنْ مَنْصُورٍ، ح وَحَدَّثَنَا عُثْمَانُ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا الأَشْجَعِيُّ، عُبَيْدُ اللَّهِ بْنُ عُبَيْدِ الرَّحْمَنِ عَنْ سُفْيَانَ الثَّوْرِيِّ، عَنِ الأَعْمَشِ، وَمَنْصُورٍ، عَنْ إِبْرَاهِيمَ، عَنْ هَمَّامٍ، عَنِ الْمِقْدَادِ، عَنِ النَّبِيِّ صلى الله عليه وسلم بِمِثْلِهِ ‏.‏\hadithno{7507}\hadithtrans{This hadith has been narrated on the authority of Miqdad through another chain of transmitters}}
\hadithdefcmd{muslim}{7508}{حَدَّثَنَا نَصْرُ بْنُ عَلِيٍّ الْجَهْضَمِيُّ، حَدَّثَنِي أَبِي، حَدَّثَنَا صَخْرٌ، - يَعْنِي ابْنَ جُوَيْرِيَةَ - عَنْ نَافِعٍ، أَنَّ عَبْدَ اللَّهِ بْنَ عُمَرَ، حَدَّثَهُ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ أَرَانِي فِي الْمَنَامِ أَتَسَوَّكُ بِسِوَاكٍ فَجَذَبَنِي رَجُلاَنِ أَحَدُهُمَا أَكْبَرُ مِنَ الآخَرِ فَنَاوَلْتُ السِّوَاكَ الأَصْغَرَ مِنْهُمَا فَقِيلَ لِي كَبِّرْ ‏.‏ فَدَفَعْتُهُ إِلَى الأَكْبَرِ ‏"‏ ‏.‏\hadithno{7508}\hadithtrans{Abdullah b. Umar reported that Allah's Messenger (ﷺ) said:It was shown in a vision that I was rinsing my mouth with miswak and two persons began to contend with one another for getting that miswak. One was older than the other. I gave the miswak to the younger one amongst them, but it was said to me: (Let it be given) to the older one. So I gave it to the older one}}
\hadithdefcmd{muslim}{7509}{حَدَّثَنَا هَارُونُ بْنُ مَعْرُوفٍ، حَدَّثَنَا بِهِ، سُفْيَانُ بْنُ عُيَيْنَةَ عَنْ هِشَامٍ، عَنْ أَبِيهِ، قَالَ كَانَ أَبُو هُرَيْرَةَ يُحَدِّثُ وَيَقُولُ اسْمَعِي يَا رَبَّةَ الْحُجْرَةِ اسْمَعِي يَا رَبَّةَ الْحُجْرَةِ ‏.‏ وَعَائِشَةُ تُصَلِّي فَلَمَّا قَضَتْ صَلاَتَهَا قَالَتْ لِعُرْوَةَ أَلاَ تَسْمَعُ إِلَى هَذَا وَمَقَالَتِهِ آنِفًا إِنَّمَا كَانَ النَّبِيُّ صلى الله عليه وسلم يُحَدِّثُ حَدِيثًا لَوْ عَدَّهُ الْعَادُّ لأَحْصَاهُ ‏.‏\hadithno{7509}\hadithtrans{It was reported that Abu Huraira used to say:Listen to me, inmate of the apartment; listen to me, inmate of the apartment, while 'A'isha (Allah be pleased with her) had been busy in observing prayer. As she finished prayer, she said to" Urwa: Did you hear his words? And this is how Allah's Messenger (ﷺ) used to utter (so distinctly) that if one intended to count (the words uttered) he would be able to do so}}
\hadithdefcmd{muslim}{7510}{حَدَّثَنَا هَدَّابُ بْنُ خَالِدٍ الأَزْدِيُّ، حَدَّثَنَا هَمَّامٌ، عَنْ زَيْدِ بْنِ أَسْلَمَ، عَنْ عَطَاءِ بْنِ يَسَارٍ، عَنْ أَبِي سَعِيدٍ الْخُدْرِيِّ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ لاَ تَكْتُبُوا عَنِّي وَمَنْ كَتَبَ عَنِّي غَيْرَ الْقُرْآنِ فَلْيَمْحُهُ وَحَدِّثُوا عَنِّي وَلاَ حَرَجَ وَمَنْ كَذَبَ عَلَىَّ - قَالَ هَمَّامٌ أَحْسِبُهُ قَالَ - مُتَعَمِّدًا فَلْيَتَبَوَّأْ مَقْعَدَهُ مِنَ النَّارِ ‏"‏ ‏.‏\hadithno{7510}\hadithtrans{Abu Sa'id Khudri reported that Allah's Messenger (ﷺ) said:Do not take down anything from me, and he who took down anything from me except the Qur'an, he should efface that and narrate from me, for there is no harm in it and he who attributed any falsehood to me-and Hammam said: I think he also said:" deliberately" -he should in fact find his abode in the Hell-Fire}}
\hadithdefcmd{muslim}{7511}{حَدَّثَنَا هَدَّابُ بْنُ خَالِدٍ، حَدَّثَنَا حَمَّادُ بْنُ سَلَمَةَ، حَدَّثَنَا ثَابِتٌ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ، أَبِي لَيْلَى عَنْ صُهَيْبٍ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ كَانَ مَلِكٌ فِيمَنْ كَانَ قَبْلَكُمْ وَكَانَ لَهُ سَاحِرٌ فَلَمَّا كَبِرَ قَالَ لِلْمَلِكِ إِنِّي قَدْ كَبِرْتُ فَابْعَثْ إِلَىَّ غُلاَمًا أُعَلِّمْهُ السِّحْرَ ‏.‏ فَبَعَثَ إِلَيْهِ غُلاَمًا يُعَلِّمُهُ فَكَانَ فِي طَرِيقِهِ إِذَا سَلَكَ رَاهِبٌ فَقَعَدَ إِلَيْهِ وَسَمِعَ كَلاَمَهُ فَأَعْجَبَهُ فَكَانَ إِذَا أَتَى السَّاحِرَ مَرَّ بِالرَّاهِبِ وَقَعَدَ إِلَيْهِ فَإِذَا أَتَى السَّاحِرَ ضَرَبَهُ فَشَكَا ذَلِكَ إِلَى الرَّاهِبِ فَقَالَ إِذَا خَشِيتَ السَّاحِرَ فَقُلْ حَبَسَنِي أَهْلِي ‏.‏ وَإِذَا خَشِيتَ أَهْلَكَ فَقُلْ حَبَسَنِي السَّاحِرُ ‏.‏ فَبَيْنَمَا هُوَ كَذَلِكَ إِذْ أَتَى عَلَى دَابَّةٍ عَظِيمَةٍ قَدْ حَبَسَتِ النَّاسَ فَقَالَ الْيَوْمَ أَعْلَمُ آلسَّاحِرُ أَفْضَلُ أَمِ الرَّاهِبُ أَفْضَلُ فَأَخَذَ حَجَرًا فَقَالَ اللَّهُمَّ إِنْ كَانَ أَمْرُ الرَّاهِبِ أَحَبَّ إِلَيْكَ مِنْ أَمْرِ السَّاحِرِ فَاقْتُلْ هَذِهِ الدَّابَّةَ حَتَّى يَمْضِيَ النَّاسُ ‏.‏ فَرَمَاهَا فَقَتَلَهَا وَمَضَى النَّاسُ فَأَتَى الرَّاهِبَ فَأَخْبَرَهُ فَقَالَ لَهُ الرَّاهِبُ أَىْ بُنَىَّ أَنْتَ الْيَوْمَ أَفْضَلُ مِنِّي ‏.‏ قَدْ بَلَغَ مِنْ أَمْرِكَ مَا أَرَى وَإِنَّكَ سَتُبْتَلَى فَإِنِ ابْتُلِيتَ فَلاَ تَدُلَّ عَلَىَّ ‏.‏ وَكَانَ الْغُلاَمُ يُبْرِئُ الأَكْمَهَ وَالأَبْرَصَ وَيُدَاوِي النَّاسَ مِنْ سَائِرِ الأَدْوَاءِ فَسَمِعَ جَلِيسٌ لِلْمَلِكِ كَانَ قَدْ عَمِيَ فَأَتَاهُ بِهَدَايَا كَثِيرَةٍ فَقَالَ مَا هَا هُنَا لَكَ أَجْمَعُ إِنْ أَنْتَ شَفَيْتَنِي فَقَالَ إِنِّي لاَ أَشْفِي أَحَدًا إِنَّمَا يَشْفِي اللَّهُ فَإِنْ أَنْتَ آمَنْتَ بِاللَّهِ دَعَوْتُ اللَّهَ فَشَفَاكَ ‏.‏ فَآمَنَ بِاللَّهِ فَشَفَاهُ اللَّهُ فَأَتَى الْمَلِكَ فَجَلَسَ إِلَيْهِ كَمَا كَانَ يَجْلِسُ فَقَالَ لَهُ الْمَلِكُ مَنْ رَدَّ عَلَيْكَ بَصَرَكَ قَالَ رَبِّي ‏.‏ قَالَ وَلَكَ رَبٌّ غَيْرِي قَالَ رَبِّي وَرَبُّكَ اللَّهُ ‏.‏ فَأَخَذَهُ فَلَمْ يَزَلْ يُعَذِّبُهُ حَتَّى دَلَّ عَلَى الْغُلاَمِ فَجِيءَ بِالْغُلاَمِ فَقَالَ لَهُ الْمَلِكُ أَىْ بُنَىَّ قَدْ بَلَغَ مِنْ سِحْرِكَ مَا تُبْرِئُ الأَكْمَهَ وَالأَبْرَصَ وَتَفْعَلُ وَتَفْعَلُ ‏.‏ فَقَالَ إِنِّي لاَ أَشْفِي أَحَدًا إِنَّمَا يَشْفِي اللَّهُ ‏.‏ فَأَخَذَهُ فَلَمْ يَزَلْ يُعَذِّبُهُ حَتَّى دَلَّ عَلَى الرَّاهِبِ فَجِيءَ بِالرَّاهِبِ فَقِيلَ لَهُ ارْجِعْ عَنْ دِينِكَ ‏.‏ فَأَبَى فَدَعَا بِالْمِئْشَارِ فَوَضَعَ الْمِئْشَارَ فِي مَفْرِقِ رَأْسِهِ فَشَقَّهُ حَتَّى وَقَعَ شِقَّاهُ ثُمَّ جِيءَ بِجَلِيسِ الْمَلِكِ فَقِيلَ لَهُ ارْجِعْ عَنْ دِينِكَ ‏.‏ فَأَبَى فَوَضَعَ الْمِئْشَارَ فِي مَفْرِقِ رَأْسِهِ فَشَقَّهُ بِهِ حَتَّى وَقَعَ شِقَّاهُ ثُمَّ جِيءَ بِالْغُلاَمِ فَقِيلَ لَهُ ارْجِعْ عَنْ دِينِكَ ‏.‏ فَأَبَى فَدَفَعَهُ إِلَى نَفَرٍ مِنْ أَصْحَابِهِ فَقَالَ اذْهَبُوا بِهِ إِلَى جَبَلِ كَذَا وَكَذَا فَاصْعَدُوا بِهِ الْجَبَلَ فَإِذَا بَلَغْتُمْ ذُرْوَتَهُ فَإِنْ رَجَعَ عَنْ دِينِهِ وَإِلاَّ فَاطْرَحُوهُ فَذَهَبُوا بِهِ فَصَعِدُوا بِهِ الْجَبَلَ فَقَالَ اللَّهُمَّ اكْفِنِيهِمْ بِمَا شِئْتَ ‏.‏ فَرَجَفَ بِهِمُ الْجَبَلُ فَسَقَطُوا وَجَاءَ يَمْشِي إِلَى الْمَلِكِ فَقَالَ لَهُ الْمَلِكُ مَا فَعَلَ أَصْحَابُكَ قَالَ كَفَانِيهِمُ اللَّهُ ‏.‏ فَدَفَعَهُ إِلَى نَفَرٍ مِنْ أَصْحَابِهِ فَقَالَ اذْهَبُوا بِهِ فَاحْمِلُوهُ فِي قُرْقُورٍ فَتَوَسَّطُوا بِهِ الْبَحْرَ فَإِنْ رَجَعَ عَنْ دِينِهِ وَإِلاَّ فَاقْذِفُوهُ ‏.‏ فَذَهَبُوا بِهِ فَقَالَ اللَّهُمَّ اكْفِنِيهِمْ بِمَا شِئْتَ ‏.‏ فَانْكَفَأَتْ بِهِمُ السَّفِينَةُ فَغَرِقُوا وَجَاءَ يَمْشِي إِلَى الْمَلِكِ فَقَالَ لَهُ الْمَلِكُ مَا فَعَلَ أَصْحَابُكَ قَالَ كَفَانِيهِمُ اللَّهُ ‏.‏ فَقَالَ لِلْمَلِكِ إِنَّكَ لَسْتَ بِقَاتِلِي حَتَّى تَفْعَلَ مَا آمُرُكَ بِهِ ‏.‏ قَالَ وَمَا هُوَ قَالَ تَجْمَعُ النَّاسَ فِي صَعِيدٍ وَاحِدٍ وَتَصْلُبُنِي عَلَى جِذْعٍ ثُمَّ خُذْ سَهْمًا مِنْ كِنَانَتِي ثُمَّ ضَعِ السَّهْمَ فِي كَبِدِ الْقَوْسِ ثُمَّ قُلْ بِاسْمِ اللَّهِ رَبِّ الْغُلاَمِ ‏.‏ ثُمَّ ارْمِنِي فَإِنَّكَ إِذَا فَعَلْتَ ذَلِكَ قَتَلْتَنِي ‏.‏ فَجَمَعَ النَّاسَ فِي صَعِيدٍ وَاحِدٍ وَصَلَبَهُ عَلَى جِذْعٍ ثُمَّ أَخَذَ سَهْمًا مِنْ كِنَانَتِهِ ثُمَّ وَضَعَ السَّهْمَ فِي كَبِدِ الْقَوْسِ ثُمَّ قَالَ بِاسْمِ اللَّهِ رَبِّ الْغُلاَمِ ‏.‏ ثُمَّ رَمَاهُ فَوَقَعَ السَّهْمُ فِي صُدْغِهِ فَوَضَعَ يَدَهُ فِي صُدْغِهِ فِي مَوْضِعِ السَّهْمِ فَمَاتَ فَقَالَ النَّاسُ آمَنَّا بِرَبِّ الْغُلاَمِ آمَنَّا بِرَبِّ الْغُلاَمِ آمَنَّا بِرَبِّ الْغُلاَمِ ‏.‏ فَأُتِيَ الْمَلِكُ فَقِيلَ لَهُ أَرَأَيْتَ مَا كُنْتَ تَحْذَرُ قَدْ وَاللَّهِ نَزَلَ بِكَ حَذَرُكَ قَدْ آمَنَ النَّاسُ ‏.‏ فَأَمَرَ بِالأُخْدُودِ فِي أَفْوَاهِ السِّكَكِ فَخُدَّتْ وَأَضْرَمَ النِّيرَانَ وَقَالَ مَنْ لَمْ يَرْجِعْ عَنْ دِينِهِ فَأَحْمُوهُ فِيهَا ‏.‏ أَوْ قِيلَ لَهُ اقْتَحِمْ ‏.‏ فَفَعَلُوا حَتَّى جَاءَتِ امْرَأَةٌ وَمَعَهَا صَبِيٌّ لَهَا فَتَقَاعَسَتْ أَنْ تَقَعَ فِيهَا فَقَالَ لَهَا الْغُلاَمُ يَا أُمَّهِ اصْبِرِي فَإِنَّكِ عَلَى الْحَقِّ ‏"‏ ‏.‏\hadithno{7511}\hadithtrans{Suhaib reported that Allah's Messenger (ﷺ) thus said:There lived a king before you and he had a (court) magician. As he (the magician) grew old, he said to the king: I have grown old, send some young boy to me so that I should teach him magic. He (the king) sent to him a young man so that he should train him (in magic). And on his way (to the magician) he (the young man) found a monk sitting there. He (the young man) listened to his (the monk's) talk and was impressed by it. It became his habit that on his way to the magician he met the monk and set there and he came to the magician (late). He (the magician) beat him because of delay. He made a complaint of that to the monk and he said to him: When you feel afraid of the magician, say: Members of my family had detained me. And when you feel afraid of your family you should say: The magician had detained me. It so happened that there came a huge beast (of prey) and it blocked the way of the people, and he (the young boy) said: I will come to know today whether the magician is superior or the monk is superior. He picked up a stone and said: O Allah, if the affair of the monk is dearer to Thee than the affair of the magician, cause death to this animal so that the people should be able to move about freely. He threw that stone towards it and killed it and the people began to move about (on the path freely). He (the young man) then came to that monk and Informed him and the monk said: Sonny, today you are superior to me. Your affair has come to a stage where I find that you would be soon put to a trial, and in case you are put to a trial don't give my clue. That young man began to treat the blind and those suffering from leprosy and he in fact began to cure people from (all kinds) of illness. When a companion of the king who had gone blind heard about him, he came to him with numerous gifts and said: If you cure me all these things collected together here would be yours. Be said: I myself do not cure anyone. It is Allah Who cures and if you affirm faith in Allah, I shall also supplicate Allah to cure you. He affirmed his faith in Allah and Allah cured him and he came to the king and sat by his side as he used to sit before. The king said to him: Who restored your eyesight? He said: My Lord. Thereupon he said: It means that your Lord is One besides me. He said: My Lord and your Lord is Allah, so he (the king) took hold of him and tormented him till he gave a clue of that boy. The young man was thus summoned and the king said to him: O boy, it has been conveyed to me that you have become so much proficient in your magic that you cure the blind and those suffering from leprosy and you do such and such things. Thereupon he said: I do not cure anyone; it is Allah Who cures, and he (the king) took hold of him and began to torment him. So he gave a clue of the monk. The monk was thus summoned and it was said to him: You should turn back from your religion. He, however, refused to do so. He (ordered) for a saw to be brought (and when it was done) he (the king) placed it in the middle of his head and tore it into parts till a part fell down. Then the courtier of the king was brought and it was said to him: Turn back from your religion. Arid he refused to do so, and the saw was placed in the midst of his head and it was torn till a part fell down. Then that young boy was brought and it was said to him: Turn back from your religion. He refused to do so and he was handed over to a group of his courtiers. And he 'said to them: Take him to such and such mountain; make him climb up that mountain and when you reach its top (ask him to renounce his faith) but if he refuses to do so, then throw him (down the mountain). So they took him and made him climb up the mountain and he said: O Allah, save me from them (in any way) Thou likest and the mountain began to quake and they all fell down and that person came walking to the king. The king said to him: What has happened to your companions? He said: Allah has saved me from them. He again handed him to some of his courtiers and said: Take him and carry him in a small boat and when you reach the middle of the ocean (ask him to renounce) his religion, but if he does not renounce his religion throw him (into the water). So they took him and he said: O Allah, save me from them and what they want to do. It was quite soon that the boat turned over and they were drowned and he came walking to the king, and the king said to him: What has happened to your companions? He said: Allah has saved me from them, and he said to the king: You cannot kill me until you do what I ask you to do. And he said: What is that? He said: You should gather people in a plain and hang me by the trunk (of a tree). Then take hold of an arrow from the quiver and say: In the name of Allah, the Lord of the young boy; then shoot an arrow and if you do that then you would be able to kill me. So he (the king) called the people in an open plain and tied him (the boy) to the trunk of a tree, then he took hold of an arrow from his quiver and then placed the arrow in the bow and then said: In the name of Allah, the Lord of the young boy; he then shot an arrow and it bit his temple. He (the boy) placed his hands upon the temple where the arrow had bit him and he died and the people said: We affirm our faith in the Lord of this young man, we affirm our faith in the Lord of this young man, we affirm our faith in the Lord of this young man. The courtiers came to the king and it was said to him: Do you see that Allah has actually done what you aimed at averting. They (the people) have affirmed their faith in the Lord. He (the king) commanded ditches to be dug at important points in the path. When these ditches were dug, and the fire was lit in them it was said (to the people): He who would not turn back from his (boy's) religion would be thrown in the fire or it would be said to them to jump in that. (The people courted death but did not renounce religion) till a woman came with her child and she felt hesitant in jumping into the fire and the child said to her: 0 mother, endure (this ordeal) for it is the Truth}}
\hadithdefcmd{muslim}{7520}{\hadithno{7520}\hadithtrans{}}
\hadithdefcmd{muslim}{7521}{حَدَّثَنِي سَلَمَةُ بْنُ شَبِيبٍ، حَدَّثَنَا الْحَسَنُ بْنُ أَعْيَنَ، حَدَّثَنَا زُهَيْرٌ، حَدَّثَنَا أَبُو إِسْحَاقَ، قَالَ سَمِعْتُ الْبَرَاءَ بْنَ عَازِبٍ، يَقُولُ جَاءَ أَبُو بَكْرٍ الصِّدِّيقُ إِلَى أَبِي فِي مَنْزِلِهِ فَاشْتَرَى مِنْهُ رَحْلاً فَقَالَ لِعَازِبٍ ابْعَثْ مَعِيَ ابْنَكَ يَحْمِلْهُ مَعِي إِلَى مَنْزِلِي فَقَالَ لِي أَبِي احْمِلْهُ ‏.‏ فَحَمَلْتُهُ وَخَرَجَ أَبِي مَعَهُ يَنْتَقِدُ ثَمَنَهُ فَقَالَ لَهُ أَبِي يَا أَبَا بَكْرٍ حَدِّثْنِي كَيْفَ صَنَعْتُمَا لَيْلَةَ سَرَيْتَ مَعَ رَسُولِ اللَّهِ صلى الله عليه وسلم قَالَ نَعَمْ أَسْرَيْنَا لَيْلَتَنَا كُلَّهَا حَتَّى قَامَ قَائِمُ الظَّهِيرَةِ وَخَلاَ الطَّرِيقُ فَلاَ يَمُرُّ فِيهِ أَحَدٌ حَتَّى رُفِعَتْ لَنَا صَخْرَةٌ طَوِيلَةٌ لَهَا ظِلٌّ لَمْ تَأْتِ عَلَيْهِ الشَّمْسُ بَعْدُ فَنَزَلْنَا عِنْدَهَا فَأَتَيْتُ الصَّخْرَةَ فَسَوَّيْتُ بِيَدِي مَكَانًا يَنَامُ فِيهِ النَّبِيُّ صلى الله عليه وسلم فِي ظِلِّهَا ثُمَّ بَسَطْتُ عَلَيْهِ فَرْوَةً ثُمَّ قُلْتُ نَمْ يَا رَسُولَ اللَّهِ وَأَنَا أَنْفُضُ لَكَ مَا حَوْلَكَ فَنَامَ وَخَرَجْتُ أَنْفُضُ مَا حَوْلَهُ فَإِذَا أَنَا بِرَاعِي غَنَمٍ مُقْبِلٍ بِغَنَمِهِ إِلَى الصَّخْرَةِ يُرِيدُ مِنْهَا الَّذِي أَرَدْنَا فَلَقِيتُهُ فَقُلْتُ لِمَنْ أَنْتَ يَا غُلاَمُ فَقَالَ لِرَجُلٍ مِنْ أَهْلِ الْمَدِينَةِ قُلْتُ أَفِي غَنَمِكَ لَبَنٌ قَالَ نَعَمْ ‏.‏ قُلْتُ أَفَتَحْلُبُ لِي قَالَ نَعَمْ ‏.‏ فَأَخَذَ شَاةً فَقُلْتُ لَهُ انْفُضِ الضَّرْعَ مِنَ الشَّعَرِ وَالتُّرَابِ وَالْقَذَى - قَالَ فَرَأَيْتُ الْبَرَاءَ يَضْرِبُ بِيَدِهِ عَلَى الأُخْرَى يَنْفُضُ - فَحَلَبَ لِي فِي قَعْبٍ مَعَهُ كُثْبَةً مِنْ لَبَنٍ قَالَ وَمَعِي إِدَاوَةٌ أَرْتَوِي فِيهَا لِلنَّبِيِّ صلى الله عليه وسلم لِيَشْرَبَ مِنْهَا وَيَتَوَضَّأَ - قَالَ - فَأَتَيْتُ النَّبِيَّ صلى الله عليه وسلم وَكَرِهْتُ أَنْ أُوقِظَهُ مِنْ نَوْمِهِ فَوَافَقْتُهُ اسْتَيْقَظَ فَصَبَبْتُ عَلَى اللَّبَنِ مِنَ الْمَاءِ حَتَّى بَرَدَ أَسْفَلُهُ فَقُلْتُ يَا رَسُولَ اللَّهِ اشْرَبْ مِنْ هَذَا اللَّبَنِ - قَالَ - فَشَرِبَ حَتَّى رَضِيتُ ثُمَّ قَالَ ‏"‏ أَلَمْ يَأْنِ لِلرَّحِيلِ ‏"‏ ‏.‏ قُلْتُ بَلَى ‏.‏ قَالَ فَارْتَحَلْنَا بَعْدَ مَا زَالَتِ الشَّمْسُ وَاتَّبَعَنَا سُرَاقَةُ بْنُ مَالِكٍ - قَالَ - وَنَحْنُ فِي جَلَدٍ مِنَ الأَرْضِ فَقُلْتُ يَا رَسُولَ اللَّهِ أُتِينَا فَقَالَ ‏"‏ لاَ تَحْزَنْ إِنَّ اللَّهَ مَعَنَا ‏"‏ ‏.‏ فَدَعَا عَلَيْهِ رَسُولُ اللَّهِ صلى الله عليه وسلم فَارْتَطَمَتْ فَرَسُهُ إِلَى بَطْنِهَا أُرَى فَقَالَ إِنِّي قَدْ عَلِمْتُ أَنَّكُمَا قَدْ دَعَوْتُمَا عَلَىَّ فَادْعُوَا لِي فَاللَّهُ لَكُمَا أَنْ أَرُدَّ عَنْكُمَا الطَّلَبَ ‏.‏ فَدَعَا اللَّهَ فَنَجَى فَرَجَعَ لاَ يَلْقَى أَحَدًا إِلاَّ قَالَ قَدْ كَفَيْتُكُمْ مَا هَا هُنَا فَلاَ يَلْقَى أَحَدًا إِلاَّ رَدَّهُ - قَالَ - وَوَفَى لَنَا ‏.‏\hadithno{7521}\hadithtrans{Al-Bara' b. 'Azib reported that Abu Bakr Siddiq came to the residence of my father ('Azib) and bought a haudaj from him and said to 'Azib:Send your son to my residence (to carry this haudaj), and my father said to me: Carry it (for him). So I carried it and there went along with him (with Abu Bakr) my father in order to fetch its price and he ('Azib) said to Abu Bakr: Abu Bakr, narrate to me what you both did on the night when you set out on a journey along with Allah's Messenger (ﷺ). He said: We set out during the night and went on walking until it was noon, and the path was vacant and so none passed by that (until) there appeared prominently before us a large rock. It had its shade and the rays of the sun did not reach that place. So we got down at that place. I then went to the rock and levelled the ground with my hands at the place where the Prophet (ﷺ) would take rest under its shade. I then set the bedding and said: Allah's Messenger, go to sleep and I shall keep a watch around you. I went out and watched around him. There we saw a shepherd moving towards that rock with his flock and he intended what we intended (i. e. taking rest). I met him and said to him: Young boy, to which place do you belong? He said: I am a person from Medina. I said, is there any milk in the udders of your sheep and goats? He said: Yes. He took hold of a goat, and I said to him: Clean the udder well so that it should be free from hair, dust and impurity. I saw al-Bara' striking his hand upon the other (to give an indication) how he did that. He milked the goat for me in a wooden cup which he had with him and I had with me a bucket in which I kept water for drinking and for performing ablution. I came to Allah's Apostle (ﷺ) and did not like to awaken him from sleep but he was accidentally startled from the sleep. I poured water upon the milk (till It was cold) and I said: Allah's Messenger, take this milk. He then took It and I was delighted and he (the Holy Prophet) said: Is now not the time to march on? I said: Of course. So he marched on after the sun had passed the meridian and Suraqa b. Malik pursued us and we had been walking on soft, level ground. I said: Allah's Messenger, we are about to be overtaken by them. Thereupon he said: Be not grieved. Verily, Allah is with us. Then Allah's Messenger (ﷺ) cursed him and his horse sank into the earth. I think he also said: I know you have hurled curse upon me. So supplicate Allah for me and I take an oath that I shall turn everyone away who would come in search of you. So he (Allah's Messenger) supplicated Allah and he was rescued and he came back and to everyone he met, he said: I have combed all this side. In short, he diverted everyone whom he met and he in fact fulfilled his promise}}
\hadithdefcmd{muslim}{7522}{وَحَدَّثَنِيهِ زُهَيْرُ بْنُ حَرْبٍ، حَدَّثَنَا عُثْمَانُ بْنُ عُمَرَ، ح وَحَدَّثَنَاهُ إِسْحَاقُ بْنُ إِبْرَاهِيمَ، أَخْبَرَنَا النَّضْرُ بْنُ شُمَيْلٍ، كِلاَهُمَا عَنْ إِسْرَائِيلَ، عَنْ أَبِي إِسْحَاقَ، عَنِ الْبَرَاءِ، قَالَ اشْتَرَى أَبُو بَكْرٍ مِنْ أَبِي رَحْلاً بِثَلاَثَةَ عَشَرَ دِرْهَمًا وَسَاقَ الْحَدِيثَ بِمَعْنَى حَدِيثِ زُهَيْرٍ عَنْ أَبِي إِسْحَاقَ وَقَالَ فِي حَدِيثِهِ مِنْ رِوَايَةِ عُثْمَانَ بْنِ عُمَرَ فَلَمَّا دَنَا دَعَا عَلَيْهِ رَسُولُ اللَّهِ صلى الله عليه وسلم فَسَاخَ فَرَسُهُ فِي الأَرْضِ إِلَى بَطْنِهِ وَوَثَبَ عَنْهُ وَقَالَ يَا مُحَمَّدُ قَدْ عَلِمْتُ أَنَّ هَذَا عَمَلُكَ فَادْعُ اللَّهَ أَنْ يُخَلِّصَنِي مِمَّا أَنَا فِيهِ وَلَكَ عَلَىَّ لأُعَمِّيَنَّ عَلَى مَنْ وَرَائِي وَهَذِهِ كِنَانَتِي فَخُذْ سَهْمًا مِنْهَا فَإِنَّكَ سَتَمُرُّ عَلَى إِبِلِي وَغِلْمَانِي بِمَكَانِ كَذَا وَكَذَا فَخُذْ مِنْهَا حَاجَتَكَ قَالَ ‏"‏ لاَ حَاجَةَ لِي فِي إِبِلِكَ ‏"‏ ‏.‏ فَقَدِمْنَا الْمَدِينَةَ لَيْلاً فَتَنَازَعُوا أَيُّهُمْ يَنْزِلُ عَلَيْهِ رَسُولُ اللَّهِ صلى الله عليه وسلم فَقَالَ ‏"‏ أَنْزِلُ عَلَى بَنِي النَّجَّارِ أَخْوَالِ عَبْدِ الْمُطَّلِبِ أُكْرِمُهُمْ بِذَلِكَ ‏"‏ ‏.‏ فَصَعِدَ الرِّجَالُ وَالنِّسَاءُ فَوْقَ الْبُيُوتِ وَتَفَرَّقَ الْغِلْمَانُ وَالْخَدَمُ فِي الطُّرُقِ يُنَادُونَ يَا مُحَمَّدُ يَا رَسُولَ اللَّهِ يَا مُحَمَّدُ يَا رَسُولَ اللَّهِ ‏.‏\hadithno{7522}\hadithtrans{Al-Bara' reported:Abu Bakr purchased a saddle from me for thirteen dirhams; the rest of the hadith is the same, and in the narration of Uthman b. 'Umar, the words are: He (Suraqa b. Malik) drew near Allah's Messenger (ﷺ), and he (the Holy Prophet) cursed him and his camel sank in the earth up to the belly and he jumped from that and said: Muhammad, I am fully aware of It that it is your doing. Supplicate Allah that He should rescue me from it in which I am (pitchforked) and I give you a solemn pledge that I shall keep this as a secret from all those who are coming after me. Take hold of an arrow out of it (quiver) for you will find my camels and my slaves at such and such place and you can get whatever you need (on showing this arrow). He (the Holy Prophet) said: I don't need your camels. And we (the Prophet and Abu Bakr) came to Medina during the night and the people began to contend as to where Allah's Messenger (ﷺ) should reside and he encamped in the tribe of Najjar who were related to 'Abd ul-Muttalib from the side of mother. Allah's Messenger (ﷺ) honoured them, then people climbed upon house-top and women also and boys scattered in the way, and they were all crying: Muhammad, Messenger of Allah, Muhammad, Messenger of Allah}}
